import { AmplicodeCommonOptions } from "../stages/options/pieces/amplicode";
import { StudioTemplateProperty } from "../../common/studio/studio-model";
import { OptionsConfig } from "../../common/cli-options";
import { YeomanGenerator } from "../YeomanGenerator";
import { GraphQLSchema } from "graphql";
import { Data } from "ejs";
export interface MvpPipelineInput<O extends AmplicodeCommonOptions, A, T> {
    /**
     * Template location.
     */
    templateDir: string;
    /**
     * All possible questions that can be asked by this generator.
     */
    questions?: StudioTemplateProperty[];
    /**
     * Defaults to {@link amplicodeCommonOptionsConfig}
     */
    optionsConfig?: OptionsConfig;
    /**
     * Can be used to replace default implementations of pipeline stages.
     */
    stages?: MvpPipelineStages<O, A, T>;
}
export type OptionsStage<O extends AmplicodeCommonOptions> = (optionsConfig: OptionsConfig, gen: YeomanGenerator) => Promise<O>;
export type ConfigStage<O extends AmplicodeCommonOptions> = (dirname: string, gen: YeomanGenerator, options: O) => Promise<void>;
export type MvpSchemaStage<O extends AmplicodeCommonOptions> = (options: O, invocationDir: string) => Promise<GraphQLSchema | undefined>;
export type MvpAnswersStage<O extends AmplicodeCommonOptions, A> = (options: O, gen: YeomanGenerator, questions?: StudioTemplateProperty[]) => Promise<A>;
export type AmplicodeTemplateModelStage<O extends AmplicodeCommonOptions, A, T> = (options: O, answers: A, schema?: GraphQLSchema) => Promise<T>;
export type MvpWriteStage<T> = (templateModel: T, gen: YeomanGenerator) => Promise<void>;
export interface MvpPipelineStages<O extends AmplicodeCommonOptions, A, T> {
    getOptions?: OptionsStage<O>;
    configureGenerator?: ConfigStage<O>;
    getGraphQLSchema?: MvpSchemaStage<O>;
    getAnswers?: MvpAnswersStage<O, A>;
    deriveTemplateModel?: AmplicodeTemplateModelStage<O, A, T>;
    write?: MvpWriteStage<T>;
}
export declare function amplicodePipeline<O extends AmplicodeCommonOptions, A, M extends Data>(input: MvpPipelineInput<O, A, M>, gen: YeomanGenerator): Promise<void>;
