"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.askQuestions = exports.defaultGetAnswersFromPrompt = void 0;
const questions_1 = require("../../../common/questions");
const refineAnswers_1 = require("./pieces/refineAnswers");
const utils_1 = require("../../../common/utils");
/**
 * Simply asks the given questions. Usable in most cases (when you don't need complex logic
 * e.g. determine whether to ask a question based on an answer to another question).
 *
 * @param projectModel
 * @param gen
 * @param options
 * @param questions
 */
const defaultGetAnswersFromPrompt = async (projectModel, gen, options, questions) => {
    if (questions == null) {
        (0, utils_1.throwError)(gen, 'Questions not provided');
    }
    const answers = await (0, exports.askQuestions)(questions, projectModel, gen);
    options.verbose && gen.log('Component config:\n' + JSON.stringify(answers));
    return answers;
};
exports.defaultGetAnswersFromPrompt = defaultGetAnswersFromPrompt;
/**
 * Asks the given questions and returns *refined* answers.
 *
 * @param questions
 * @param projectModel
 * @param gen
 */
const askQuestions = async (questions, projectModel, gen) => {
    const rawAnswers = await gen.prompt((0, questions_1.fromStudioProperties)(questions, projectModel));
    return (0, refineAnswers_1.refineAnswers)(projectModel, questions, rawAnswers);
};
exports.askQuestions = askQuestions;
//# sourceMappingURL=defaultGetAnswersFromPrompt.js.map