"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.refineAnswers = void 0;
const cuba_model_utils_1 = require("../../../../common/model/cuba-model-utils");
/**
 * This function takes the answers and adds context / additional data retrieved from project model
 *
 * @param projectModel
 * @param generatorParams
 * @param answers
 */
function refineAnswers(projectModel, generatorParams, answers) {
    const refinedAnswers = {};
    if (answers == null)
        return refinedAnswers;
    Object.keys(answers).forEach((key) => {
        const prop = generatorParams.find(p => p.code === key);
        // leave answer as is if it is not exist in props
        if (prop == null) {
            refinedAnswers[key] = answers[key];
            return;
        }
        switch (prop.propertyType) {
            case "ENTITY" /* StudioTemplatePropertyType.ENTITY */:
                refinedAnswers[key] = (0, cuba_model_utils_1.findEntity)(projectModel, answers[key]);
                return;
            case "VIEW" /* StudioTemplatePropertyType.VIEW */:
                refinedAnswers[key] = (0, cuba_model_utils_1.findView)(projectModel, answers[key]);
                return;
            case "REST_QUERY" /* StudioTemplatePropertyType.REST_QUERY */:
                refinedAnswers[key] = (0, cuba_model_utils_1.findQuery)(projectModel, answers[key]);
                return;
            case "REST_SERVICE_METHOD" /* StudioTemplatePropertyType.REST_SERVICE_METHOD */:
                refinedAnswers[key] = (0, cuba_model_utils_1.findServiceMethod)(projectModel, answers[key]);
                return;
            case "MENU_ITEM" /* StudioTemplatePropertyType.MENU_ITEM */:
                refinedAnswers[key] = answers[key] ?? null;
                return;
            case "INTEGER" /* StudioTemplatePropertyType.INTEGER */: {
                const value = answers[key];
                if (!Number.isInteger(value))
                    throw new Error(`Question with code '${key}' has INTEGER type and can't contain '${value}' as answer`);
                refinedAnswers[key] = value;
                return;
            }
            default:
                refinedAnswers[key] = answers[key];
        }
    });
    return refinedAnswers;
}
exports.refineAnswers = refineAnswers;
//# sourceMappingURL=refineAnswers.js.map