"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFormatTransform = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const through2_1 = tslib_1.__importDefault(require("through2"));
const prettier_1 = tslib_1.__importDefault(require("prettier"));
const organizeImportsPlugin = tslib_1.__importStar(require("prettier-plugin-organize-imports"));
/**
 * Prettier formatting transform stream for .ts and .tsx files
 */
function createFormatTransform() {
    return through2_1.default.obj(formatTransform);
}
exports.createFormatTransform = createFormatTransform;
async function formatTransform(file, _enc, callback) {
    if (isTsTsxFile(file) && !isFileExcludedFromFormatting(file.path)) {
        const content = Buffer.from(file.contents).toString('utf8')
            // remove ejs formatting spaces before 'import' line
            .replace(/^\s*import /gm, 'import ')
            // remove ejs empty lines between imports
            .replace(/^\s*[\r\n]import /gm, 'import ');
        const formattedContent = await prettier_1.default.format(content, {
            parser: "typescript",
            printWidth: 100,
            trailingComma: "es5",
            plugins: [organizeImportsPlugin]
        });
        file.contents = Buffer.from(formattedContent);
        // @ts-ignore
        this.push(file);
    }
    return callback();
}
function isTsTsxFile(file) {
    return (file.path.endsWith('.ts') || file.path.endsWith('.tsx')) && file.contents != null;
}
function isFileExcludedFromFormatting(filePath) {
    const devDir = path_1.default.join('src', 'dev');
    // Prettier formatting breaks React Buddy templates
    return (filePath.endsWith('Template.tsx') || filePath.endsWith('palette.tsx')) && filePath.includes(devDir);
}
//# sourceMappingURL=createFormatTransform.js.map