"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.amplicodeGetGraphQLSchema = void 0;
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const fs = tslib_1.__importStar(require("fs"));
const load_1 = require("@graphql-tools/load");
const amplicodeGetGraphQLSchema = async (options, invocationDir) => {
    if (!Array.isArray(options.schema) || options.schema.length < 1) {
        throw new Error(`GraphQL schema not passed in options`);
    }
    const schemaPaths = options.schema[0];
    console.log(`amplicodeGetGraphQLSchema: read schema list from paths '${JSON.stringify(schemaPaths)}'`);
    const schemaStringArray = [];
    for (const schemaPath of schemaPaths) {
        const absolutePath = path.isAbsolute(schemaPath) ? schemaPath : path.join(invocationDir, schemaPath);
        schemaStringArray.push(await readSchemaFile(absolutePath));
    }
    // Schema files should be SDL format, introspection JSON format is not supported
    return await (0, load_1.loadSchema)(schemaStringArray, { loaders: [] });
};
exports.amplicodeGetGraphQLSchema = amplicodeGetGraphQLSchema;
async function readSchemaFile(schemaPathAbsolute) {
    console.log(`readSchemaFile from '${schemaPathAbsolute}'`);
    if (!fs.existsSync(schemaPathAbsolute) || fs.lstatSync(schemaPathAbsolute).isDirectory()) {
        throw new Error(`GraphQL schema not found at "${schemaPathAbsolute}"`);
    }
    return fs.readFileSync(schemaPathAbsolute, 'utf-8');
}
//# sourceMappingURL=amplicodeGetGraphQLSchema.js.map