import { GqlAttributeModel } from "./entity";
export declare class SpreadElement {
    __type__: string;
}
export type I18nMessages<K extends string = string> = {
    [P in K]: I18nMessages | SpreadElement | string;
};
/**
 * Generate messages that should be added to app message pack (en.ts)
 * for translate entity resource name and fields.
 * Generated messages based on information from graphQL query - entity name and attributes.
 *
 * @param entityName - entity name string.
 * If entity name ends with 'Dto' or 'DTO' - this suffix will be removed in 'name' message.
 * @param attributes - graphQL attributes from graphQL query as GqlAttributeModel[]
 *
 * @returns messages as typescript object (react-admin i18n format),
 * which contains resource name, fields and enums:
 * {
 *  resource: {
 *    Entity: {
 *      name: "Entity |||| Entities",
 *      fields: {
 *        key: "value",
 *      },
 *    }
 *  },
 *  enums: {
 *    EnumTypeName: {
 *      VALUE_ONE: "Value one",
 *      VALUE_TWO: "Value two",
 *    }
 *  }
 * }
 *
 * Note: react-admin used `||||` as separator between singular and plural name forms.
 *
 */
export declare function getI18nMessages(entityName: string, attributes: GqlAttributeModel[]): I18nMessages;
