"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_commons_1 = require("../../../../../test/test-commons");
const getGraphQLTypeByRelativePath_1 = require("./getGraphQLTypeByRelativePath");
const chai_1 = require("chai");
describe('getGraphQLTypeByRelativePath', async () => {
    let schema;
    before(async () => {
        schema = await (0, test_commons_1.getMockSchema)();
    });
    it('with mutation startField', () => {
        const mutationType = schema.getMutationType();
        if (mutationType == null)
            throw new Error();
        const petType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, mutationType, ['updatePet']);
        (0, chai_1.expect)(petType.toString()).to.eq('PetDTO');
        const identificationNumberType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, mutationType, ['updatePet', 'identificationNumber']);
        (0, chai_1.expect)(identificationNumberType.toString()).to.eq('String!');
    });
    it('with query startField', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const petType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet']);
        (0, chai_1.expect)(petType.toString()).to.eq('PetDTO');
        const identificationNumberType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet', 'identificationNumber']);
        (0, chai_1.expect)(identificationNumberType.toString()).to.eq('String!');
    });
    it('in root of query', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const queryStringType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, []);
        (0, chai_1.expect)(queryStringType.toString()).to.eq('Query');
        const petType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet']);
        const petStringType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, petType, []);
        (0, chai_1.expect)(petStringType.toString()).to.eq('PetDTO');
        const petListType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['petList']);
        const petListStringType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, petListType, []);
        (0, chai_1.expect)(petListStringType.toString()).to.eq('[PetDTO]');
    });
    // TODO enable when TestDTO will be added to the graphql schema
    xit('with primitive', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const testType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['testList']);
        const floatType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['floatTest']);
        (0, chai_1.expect)(floatType).to.eq('Float');
        const intType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['intTest']);
        (0, chai_1.expect)(intType).to.eq('Int');
        const booleanType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['bool']);
        (0, chai_1.expect)(booleanType).to.eq('Boolean');
        const stringType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['string']);
        (0, chai_1.expect)(stringType).to.eq('String');
    });
    // TODO enable when TestDTO will be added to the graphql schema
    xit('with date', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const testType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['testList']);
        const localDateType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['localDate']);
        (0, chai_1.expect)(localDateType).to.eq('Date');
        const localDateTimeType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['localDateTime']);
        (0, chai_1.expect)(localDateTimeType).to.eq('DateTime');
        const localTimeType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['localTime']);
        (0, chai_1.expect)(localTimeType).to.eq('Time');
    });
    // TODO enable when TestDTO will be added to the graphql schema
    xit('with not null', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const testType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['testList']);
        const strictBooleanType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['boolPrimitive']);
        (0, chai_1.expect)(strictBooleanType).to.eq('Boolean!');
        const strictIntType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, testType, ['bytePrimitive']);
        (0, chai_1.expect)(strictIntType).to.eq('Int!');
    });
    it('with array', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const petListType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['petList']);
        (0, chai_1.expect)(petListType.toString()).to.eq('[PetDTO]');
    });
    it('get type by deep path', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const ownerType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet', 'owner']);
        (0, chai_1.expect)(ownerType.toString()).to.eq('OwnerDTO');
        const ownerCityType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet', 'owner', 'city']);
        (0, chai_1.expect)(ownerCityType.toString()).to.eq('String');
        const ownerEmailType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet', 'owner', 'email']);
        (0, chai_1.expect)(ownerEmailType.toString()).to.eq('String');
        const petTypeType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet', 'type']);
        (0, chai_1.expect)(petTypeType.toString()).to.eq('PetTypeDTO');
        const petTypeNameType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, queryType, ['pet', 'type', 'name']);
        (0, chai_1.expect)(petTypeNameType.toString()).to.eq('String');
    });
    it('in argument', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const filterArgType = queryType.getFields()['ownerByNamesList'].args.find(({ name }) => name === 'filter')?.type;
        if (filterArgType == null)
            throw new Error();
        (0, chai_1.expect)(filterArgType.toString()).to.eq('OwnerFilterInput');
        const firstNameType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, filterArgType, ['firstName']);
        (0, chai_1.expect)(firstNameType.toString()).to.eq('String');
        const lastNameType = (0, getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath)(schema, filterArgType, ['lastName']);
        (0, chai_1.expect)(lastNameType.toString()).to.eq('String');
    });
});
//# sourceMappingURL=getGraphQLTypeByRelativePath.test.js.map