"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeAddonsPalette = exports.removeAddonImport = exports.addAddonPalette = exports.addAddonImport = void 0;
const tslib_1 = require("tslib");
const jscodeshift_1 = tslib_1.__importStar(require("jscodeshift"));
const path_1 = tslib_1.__importDefault(require("path"));
// @deprecated - The code is not used. We keep it as the example of working with the jscodeshift library
function addAddonImport(gen, dirShift, addonPackageName) {
    const addonsAst = getAddonsAST(gen, dirShift);
    if (addonsAst === null) {
        gen.log('Unable to add addons import: addons.ts file not found');
        return;
    }
    if (isAddonAlreadyImported(addonsAst, addonPackageName)) {
        gen.log(`addon ${addonPackageName} is already imported`);
        return;
    }
    injectAddonImport(gen, dirShift, addonsAst, addonPackageName);
}
exports.addAddonImport = addAddonImport;
// @deprecated - The code is not used. We keep it as the example of working with the jscodeshift library
function addAddonPalette(gen, dirShift, paletteComponentName, addonPackageName) {
    const appPalettePath = getPalettePath(gen, dirShift);
    if (!gen.fs.exists(appPalettePath)) {
        gen.log(`Unable to add addon's palette to app palette: app palette not found`);
        return;
    }
    const appPaletteContents = gen.fs.read(appPalettePath);
    const updatedAppPaletteContentns = injectAddonPalette(appPaletteContents, addonPackageName, paletteComponentName);
    gen.fs.write(appPalettePath, updatedAppPaletteContentns);
}
exports.addAddonPalette = addAddonPalette;
// @deprecated - The code is not used. We keep it as the example of working with the jscodeshift library
function removeAddonImport(gen, dirShift, addonPackageName) {
    const addonsAst = getAddonsAST(gen, dirShift);
    if (addonsAst === null) {
        gen.log(`Unable to remove ${addonPackageName} addon from addons.ts: addons.ts file not found`);
        return;
    }
    const addonImport = addonsAst
        .find(jscodeshift_1.ImportDeclaration)
        .filter((path) => {
        return path.value.source.value === addonPackageName;
    });
    if (addonImport.length === 0) {
        gen.log(`Unable to remove ${addonPackageName} addon from addons.ts: addons.ts doesn't contain this import`);
        return;
    }
    addonImport.remove();
    gen.fs.write(getAddonsPath(gen, dirShift), addonImport.toSource());
}
exports.removeAddonImport = removeAddonImport;
// @deprecated - The code is not used. We keep it as the example of working with the jscodeshift library
function removeAddonsPalette(gen, dirShift, addonPackageName) {
    const paletteAst = getPaletteAST(gen, dirShift);
    if (paletteAst === null) {
        gen.log(`Unable to remove ${addonPackageName} palette from palette.ts: palette.ts file not found`);
        return;
    }
    const addonPaletteModulePath = `${addonPackageName}/palette`;
    const addonImport = paletteAst
        .find(jscodeshift_1.ImportDeclaration)
        .filter((path) => {
        return path.value.source.value === addonPaletteModulePath;
    });
    if (addonImport.length === 0) {
        gen.log(`Unable to remove ${addonPackageName} palette from palette.ts: palette.ts doesn't contain this import`);
        return;
    }
    const addonPaletteComponentName = addonImport
        .find(jscodeshift_1.ImportSpecifier)
        .nodes()[0].imported.name;
    const addonComponentPaletteJsxNodes = paletteAst.findJSXElements(addonPaletteComponentName);
    addonImport.remove();
    addonComponentPaletteJsxNodes.remove();
    gen.fs.write(getPalettePath(gen, dirShift), addonImport.toSource());
}
exports.removeAddonsPalette = removeAddonsPalette;
function getAddonsAST(gen, dirShift) {
    const addonsPath = getAddonsPath(gen, dirShift);
    if (!gen.fs.exists(addonsPath)) {
        return null;
    }
    const addonsContents = gen.fs.read(addonsPath);
    const tsxParser = jscodeshift_1.default.withParser('tsx');
    return tsxParser(addonsContents);
}
function injectAddonImport(gen, dirShift, addonsAST, addonPackageName) {
    const transformedAddonsContent = transformAddonsContent(addonsAST.toSource(), addonPackageName);
    gen.fs.write(getAddonsPath(gen, dirShift), transformedAddonsContent);
}
function getAddonsPath(gen, dirShift) {
    return path_1.default.join(gen.destinationRoot(), dirShift ?? '', 'core', 'addons', 'addons.ts');
}
function transformAddonsContent(content, addonPackageName) {
    return `import '${addonPackageName}'; 
    ${content}`;
}
function isAddonAlreadyImported(ast, addonPackageName) {
    return ast
        .find(jscodeshift_1.ImportDeclaration)
        .filter(path => path.node.source.value === addonPackageName)
        .length > 0;
}
function getPalettePath(gen, dirShift) {
    return path_1.default.join(gen.destinationRoot(), dirShift ? dirShift : '', 'dev', 'palette.tsx');
}
function getPaletteAST(gen, dirShift) {
    const palettePath = getPalettePath(gen, dirShift);
    if (!gen.fs.exists(palettePath)) {
        return null;
    }
    const paletteContents = gen.fs.read(palettePath);
    const tsxParser = jscodeshift_1.default.withParser('tsx');
    return tsxParser(paletteContents);
}
function injectAddonPalette(appPaletteContents, addonPackageName, paletteComponentName) {
    const tsxParser = jscodeshift_1.default.withParser('tsx');
    const paletteAst = tsxParser(appPaletteContents);
    if (isPaletteAlreadyImported(paletteAst, paletteComponentName)) {
        return appPaletteContents;
    }
    injectPaletteImport(paletteAst, paletteComponentName, addonPackageName);
    injectPaletteComponent(paletteAst, paletteComponentName);
    return paletteAst.toSource();
}
function createAddonPaletteJSX(paletteComponentName) {
    return `<${paletteComponentName}/>`;
}
function isPaletteAlreadyImported(ast, paletteComponentName) {
    return ast.find(jscodeshift_1.ImportDeclaration)
        .find(jscodeshift_1.ImportSpecifier)
        .filter(path => path.node.imported.name === paletteComponentName)
        .length > 0;
}
function injectPaletteImport(ast, paletteComponentName, addonPackageName) {
    const addonPaletteImport = (0, jscodeshift_1.importDeclaration)([(0, jscodeshift_1.importSpecifier)((0, jscodeshift_1.identifier)(paletteComponentName))], (0, jscodeshift_1.stringLiteral)(`${addonPackageName}/palette`));
    ast.get().node.program.body.unshift(addonPaletteImport);
}
function injectPaletteComponent(ast, paletteComponentName) {
    const paletteAddonJSX = createAddonPaletteJSX(paletteComponentName);
    const palette = ast.findJSXElements('Palette');
    const [{ value: { children } }] = palette.paths();
    children?.push((0, jscodeshift_1.stringLiteral)(paletteAddonJSX));
}
//# sourceMappingURL=addons.js.map