"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const insertSpecifierImport_1 = require("./insertSpecifierImport");
const parseTs_1 = require("../../../../util/parseTs");
describe("insertSpecifierImport", () => {
    it("should insert import to empty file", () => {
        const appAST = (0, parseTs_1.parseTs)("");
        (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, "Component", "react");
        (0, chai_1.expect)(appAST.toSource()).eq(`import { Component } from "react";`);
        (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, "Component", "react");
        (0, chai_1.expect)(appAST.toSource()).eq(`import { Component } from "react";`);
    });
    it("should insert specifier import to existing import", () => {
        const appAST = (0, parseTs_1.parseTs)(`import { anyThing } from "anyModule"; import { OtherThing } from "react";`);
        (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, "Component", "react");
        (0, chai_1.expect)(appAST.toSource())
            .eq(`import { anyThing } from "anyModule"; import { OtherThing, Component } from "react";`);
    });
    it("should do nothing if import already exist", function () {
        const appAST = (0, parseTs_1.parseTs)(`import { anyThing } from "anyModule"; import { OtherThing } from "react";`);
        (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, "anyThing", "anyModule");
        (0, chai_1.expect)(appAST.toSource())
            .eq(`import { anyThing } from "anyModule"; import { OtherThing } from "react";`);
    });
    it("should throw error if specifier exist in different module", function () {
        const appAST = (0, parseTs_1.parseTs)(`import { PetCreateAdvanced } from "./screens/pet/PetCreateAdvanced";`);
        (0, chai_1.expect)(() => (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, "PetCreateAdvanced", "../PetCreateAdvanced"))
            .to.throw(`Import specifier 'PetCreateAdvanced' already exist in different module`);
    });
});
//# sourceMappingURL=insertSpecifierImport.test.js.map