"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const parseExpression_1 = require("./parseExpression");
describe('parseExpression', () => {
    it('Struct of primitives', () => {
        const stringExpression = (0, parseExpression_1.parseExpression)(`"string"`);
        (0, chai_1.expect)(stringExpression.type).eq("StringLiteral");
        if (stringExpression.type === 'StringLiteral') {
            (0, chai_1.expect)(stringExpression.value).eq("string");
        }
        const numberExpression = (0, parseExpression_1.parseExpression)('0');
        (0, chai_1.expect)(numberExpression.type).eq("NumericLiteral");
        if (numberExpression.type === 'NumericLiteral') {
            (0, chai_1.expect)(numberExpression.value).eq(0);
        }
        const boolExpression = (0, parseExpression_1.parseExpression)('true');
        (0, chai_1.expect)(boolExpression.type).eq("BooleanLiteral");
        if (boolExpression.type === 'BooleanLiteral') {
            (0, chai_1.expect)(boolExpression.value).eq(true);
        }
    });
    it('Struct of object', () => {
        const object = (0, parseExpression_1.parseExpression)(`{
      number: 0,
      string: "string",
    }`);
        if (object.type === 'ObjectExpression') {
            if (object.properties[0].type === 'ObjectProperty') {
                if (object.properties[0].key.type === 'Identifier') {
                    (0, chai_1.expect)(object.properties[0].key.name).eq('number');
                }
                if (object.properties[0].value.type === 'NumericLiteral') {
                    (0, chai_1.expect)(object.properties[0].value.value).eq(0);
                }
            }
            if (object.properties[1].type === 'ObjectProperty') {
                if (object.properties[1].key.type === 'Identifier') {
                    (0, chai_1.expect)(object.properties[1].key.name).eq('string');
                }
                if (object.properties[1].value.type === 'StringLiteral') {
                    (0, chai_1.expect)(object.properties[1].value.value).eq('string');
                }
            }
        }
    });
    it('Struct of array', () => {
        const array = (0, parseExpression_1.parseExpression)('[0, "string", true]');
        (0, chai_1.expect)(array.type).eq('ArrayExpression');
        if (array.type === 'ArrayExpression') {
            if (array.elements[0]?.type === 'NumericLiteral') {
                (0, chai_1.expect)(array.elements[0].value).eq(0);
            }
            if (array.elements[1]?.type === 'StringLiteral') {
                (0, chai_1.expect)(array.elements[1].value).eq('string');
            }
            if (array.elements[2]?.type === 'BooleanLiteral') {
                (0, chai_1.expect)(array.elements[2].value).eq(true);
            }
        }
    });
    it('Struct of jsx', () => {
        const jsx = (0, parseExpression_1.parseExpression)('<div numberProp={0}>{"childText"}</div>');
        (0, chai_1.expect)(jsx.type).eq("JSXElement");
        if (jsx.type === 'JSXElement') {
            if (jsx.openingElement.type === 'JSXOpeningElement') {
                if (jsx.openingElement.name.type === 'JSXIdentifier') {
                    (0, chai_1.expect)(jsx.openingElement.name.name).eq('div');
                }
                if (jsx.openingElement.attributes?.[0].type === 'JSXAttribute') {
                    (0, chai_1.expect)(jsx.openingElement.attributes?.[0].name.name).eq('numberProp');
                }
            }
            if (jsx.closingElement?.type === 'JSXClosingElement') {
                if (jsx.closingElement.name.type === 'JSXIdentifier') {
                    (0, chai_1.expect)(jsx.closingElement.name.name).eq('div');
                }
            }
            if (jsx.children?.[0].type === 'JSXExpressionContainer') {
                if (jsx.children?.[0].expression.type === 'StringLiteral') {
                    (0, chai_1.expect)(jsx.children?.[0].expression.value).eq("childText");
                }
            }
        }
    });
});
//# sourceMappingURL=parseExpression.test.js.map