"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformAddRouteItem = exports.transformAddRouteImport = exports.transformAddMenuItem = exports.addMvpAppMenu = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const jscodeshift_1 = tslib_1.__importDefault(require("jscodeshift"));
const utils_1 = require("../../../../../common/utils");
const parseExpression_1 = require("../jsCodeShift/parseExpression");
const toSource_1 = require("../jsCodeShift/toSource");
const tsxParser = jscodeshift_1.default.withParser('tsx');
function addMvpAppMenu({ gen, dirShift, route, routeType, componentName, menuItemName, pathToComponent }) {
    const destRoot = gen.destinationRoot();
    const srcDir = path_1.default.join(destRoot, dirShift ? dirShift : '');
    // Add menu item
    const appMenuPath = path_1.default.join(srcDir, 'app', 'menu', 'Menu.tsx');
    if (!gen.fs.exists(appMenuPath)) {
        // old version (antd) - do not log it, confused in ra-version generators
        // gen.log(`Unable to add component to menu: app menu file not found in path '${appMenuPath}'`);
        return;
    }
    const appMenuContents = gen.fs.read(appMenuPath);
    const appMenuTransformed = transformAddMenuItem(appMenuContents, route, componentName, menuItemName);
    gen.fs.write(appMenuPath, appMenuTransformed);
    gen.log(`✓ Menu item added for ${componentName}`);
    // Add route
    const routeConfigPath = path_1.default.join(srcDir, 'app', 'routes', 'AppRoutes.tsx');
    if (!gen.fs.exists(routeConfigPath)) {
        gen.log(`Unable to add component: route config file not found in path '${routeConfigPath}'`);
        return;
    }
    const routeConfigFileContent = gen.fs.read(routeConfigPath);
    let routeConfigTransformed;
    routeConfigTransformed = transformAddRouteItem(routeConfigFileContent, route, routeType ?? 'with-record-id', componentName);
    gen.log(`✓ Route item added for ${componentName}`);
    const componentPath = pathToComponent ?? `${getRelativePath(path_1.default.join(srcDir, 'app/routes'), destRoot)}/${componentName}`;
    routeConfigTransformed = transformAddRouteImport(routeConfigTransformed, componentName, componentPath);
    gen.fs.write(routeConfigPath, routeConfigTransformed);
    gen.log(`✓ Route import for ${componentName}`);
}
exports.addMvpAppMenu = addMvpAppMenu;
function transformAddMenuItem(source, route, componentName, menuItemName) {
    const appMenuAST = tsxParser(source);
    const menu = appMenuAST
        .findVariableDeclarators('menuItems')
        .find(jscodeshift_1.default.ArrayExpression);
    const [{ value: { elements } }] = menu.paths();
    const newMenuItem = generateMenuItemAst(route, componentName, menuItemName);
    elements.push(newMenuItem);
    return (0, toSource_1.toSource)(appMenuAST);
}
exports.transformAddMenuItem = transformAddMenuItem;
function transformAddRouteImport(source, componentName, componentPath, isDefault = false) {
    const ast = tsxParser(source);
    const existingSpecifiers = ast.find(jscodeshift_1.default.ImportDeclaration)
        .find(jscodeshift_1.default.ImportSpecifier)
        .filter(path => path.node.imported.name === componentName);
    const alreadyImported = existingSpecifiers.length > 0;
    if (alreadyImported) {
        return source;
    }
    const importSpecifier = isDefault ? jscodeshift_1.default.importDefaultSpecifier : jscodeshift_1.default.importSpecifier;
    const newImport = jscodeshift_1.default.importDeclaration([importSpecifier(jscodeshift_1.default.identifier(componentName))], jscodeshift_1.default.stringLiteral(componentPath));
    ast.get().node.program.body.unshift(newImport);
    return (0, toSource_1.toSource)(ast);
}
exports.transformAddRouteImport = transformAddRouteImport;
function transformAddRouteItem(source, route, routeType, componentName) {
    const routeConfigAST = tsxParser(source);
    const menu = routeConfigAST.findJSXElements('Routes');
    const [{ value: { children } }] = menu.paths();
    const routeItemJSX = routeType === 'simple'
        ? createSimpleRouteItemJSX(route, componentName)
        : createRouteItemJSX(route, componentName);
    children?.push(jscodeshift_1.default.stringLiteral(routeItemJSX));
    return (0, toSource_1.toSource)(routeConfigAST);
}
exports.transformAddRouteItem = transformAddRouteItem;
function generateMenuItemAst(route, componentName, menuItemName) {
    const menuItem = `
    {
      label: (
        <Link to="${route}">
          <FormattedMessage id="screen.${menuItemName ?? componentName}" />
        </Link>
      ),
      key: "${route}"
    }
  `;
    return (0, parseExpression_1.parseExpression)(menuItem);
}
function createRouteItemJSX(route, componentName) {
    return `
    <Route path="${route}">
      <Route index element={<${componentName}/>} />
      <Route path=":recordId" element={<${componentName}/>} />
    </Route>
  `;
}
function createSimpleRouteItemJSX(route, componentName) {
    return `
   <Route path="${route}" element={<${componentName}/>} />
  `;
}
function getRelativePath(routingDir, destRoot) {
    return (0, utils_1.convertToUnixPath)(path_1.default.relative(routingDir, destRoot));
}
//# sourceMappingURL=addMvpAppMenu.js.map