"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const addMvpAppMenu_1 = require("./addMvpAppMenu");
const chai_1 = tslib_1.__importStar(require("chai"));
const chai_string_1 = tslib_1.__importDefault(require("chai-string"));
chai_1.default.use(chai_string_1.default);
describe('transformAddRouteItem', () => {
    it('adds a route item with record id', () => {
        const result = (0, addMvpAppMenu_1.transformAddRouteItem)(ADD_ROUTE_ITEM_INPUT, 'pet-list', 'with-record-id', 'PetList');
        (0, chai_1.expect)(result).to.equalIgnoreSpaces(`
      export function AppRoutes() {
        return (
          (<Routes>
            <Route path="pet-list">
                  <Route index element={<PetList/>} />
                  <Route path=":recordId" element={<PetList/>} />
                </Route></Routes>)
        );
      }
    `);
    });
    it('adds a simple route item', () => {
        const result = (0, addMvpAppMenu_1.transformAddRouteItem)(ADD_ROUTE_ITEM_INPUT, 'pet-list', 'simple', 'PetList');
        (0, chai_1.expect)(result).to.equalIgnoreSpaces(`
      export function AppRoutes() {
        return (
          (<Routes>
            <Route path="pet-list" element={<PetList/>} />
          </Routes>)
        );
      }
    `);
    });
});
const ADD_ROUTE_ITEM_INPUT = `
export function AppRoutes() {
  return (
    <Routes>
    </Routes>
  );
}`;
describe('transformAddRouteImport', () => {
    it('adds an import successfully', () => {
        const result = (0, addMvpAppMenu_1.transformAddRouteImport)(ADD_ROUTE_IMPORTS_INPUT, 'PetList', './pet-list/PetList');
        (0, chai_1.expect)(result).to.be.eq(ADD_ROUTE_IMPORTS_EXPECTED);
    });
});
const ADD_ROUTE_IMPORTS_INPUT = `
import { Home } from "./home/Home";
import { ReactComponent } from "../framework/screen-api/ReactComponent";`;
const ADD_ROUTE_IMPORTS_EXPECTED = `
import { PetList } from "./pet-list/PetList";
import { Home } from "./home/Home";
import { ReactComponent } from "../framework/screen-api/ReactComponent";`;
describe('transformAddMenuItem', () => {
    it('adds a menu item successfully', () => {
        const result = (0, addMvpAppMenu_1.transformAddMenuItem)(ADD_MENU_ITEM_INPUT, "pet-list", 'PetListScreenLayout');
        (0, chai_1.expect)(result).to.be.eq(ADD_MENU_ITEM_EXPECTED);
    });
});
const ADD_MENU_ITEM_INPUT = `
const menuItems: ItemType[] = [];`;
const ADD_MENU_ITEM_EXPECTED = `
const menuItems: ItemType[] = [{
  label: (
    <Link to="pet-list">
      <FormattedMessage id="screen.PetListScreenLayout" />
    </Link>
  ),
  key: "pet-list"
}];`;
//# sourceMappingURL=addMvpAppMenu.test.js.map