"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addLinkToMenu = void 0;
const tslib_1 = require("tslib");
const jscodeshift_1 = tslib_1.__importDefault(require("jscodeshift"));
const insertSpecifierImport_1 = require("../jsCodeShift/insertSpecifierImport");
const getMenuTagChildren_1 = require("./getMenuTagChildren");
const toSource_1 = require("../jsCodeShift/toSource");
/**
 * Add component to menu. If MenuItem with the same componentName in the primaryText prop already exist - do nothing.
 * Example of added line `<Menu.Item  to="/BlankComponent" primaryText="BlankComponent" />`;
 *
 * @param menuInput jsx menu as test
 * @param route routing path to component
 * @param componentName name of component to be added in menu
 * @param primaryTextPrefix prefix for i18n message
 */
function addLinkToMenu(menuInput, route, componentName, primaryTextPrefix = "routes") {
    const tsxParser = jscodeshift_1.default.withParser("tsx");
    const appMenuAST = tsxParser(menuInput);
    // check, if such MenuItem item already exist in menu
    const isItemAlreadyExist = appMenuAST
        .findJSXElements("MenuItemSecured")
        .nodes()
        .some((el) => {
        const openingEl = el.openingElement;
        // looking for MenuItem like `<MenuItemSecured  to="/BlankComponent" primaryText="BlankComponent" />`,
        // where BlankComponent is componentName
        return openingEl?.attributes?.some((attr) => attr.name.name === "primaryText" && attr.value.value === componentName);
    });
    if (!isItemAlreadyExist) {
        const menuItemTag = `` +
            `<MenuItemSecured name="${componentName}" to="${route}" `
            + `primaryText="${primaryTextPrefix}.${componentName}" leftIcon={<WebAsset />} />`;
        const menuItemTagNode = (0, jscodeshift_1.default)(menuItemTag).findJSXElements().nodes()[0];
        (0, getMenuTagChildren_1.getMenuTagChildren)(appMenuAST).push(menuItemTagNode);
        (0, insertSpecifierImport_1.insertSpecifierImport)(appMenuAST, "MenuItemSecured", "../../core/security/components/MenuItemSecured");
        (0, insertSpecifierImport_1.insertSpecifierImport)(appMenuAST, "WebAsset", "@mui/icons-material");
        console.log(`addMenuItemToMenu: menuItem added to menu\n ${menuItemTag}`);
    }
    else {
        console.log(`addMenuItemToMenu: skip adding MenuItem to menu, MenuItem ${componentName} already exist`);
    }
    return (0, toSource_1.toSource)(appMenuAST);
}
exports.addLinkToMenu = addLinkToMenu;
//# sourceMappingURL=addLinkToMenu.js.map