"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const addLinkToMenu_1 = require("./addLinkToMenu");
const chai_1 = require("chai");
describe("addLinkToMenu", () => {
    const route = '/route';
    const MENU_INPUT = `
    <Menu>
      <Menu.DashboardItem />
      <Menu.ResourceItem name="OwnerDTO" />
      <MenuItemSecured  to="/OldComponent" primaryText="OldComponent" />
    </Menu>
  `;
    it("should add menu item to menu, if item not exist", function () {
        const componentName = "NewComponent";
        const res = (0, addLinkToMenu_1.addLinkToMenu)(MENU_INPUT, route, componentName);
        (0, chai_1.expect)(res).to.contain(`<MenuItemSecured name="NewComponent" to="/route" primaryText="routes.NewComponent" leftIcon={<WebAsset />} />`);
        (0, chai_1.expect)(res).to.contain(`import { MenuItemSecured } from "../../core/security/components/MenuItemSecured";`);
    });
    it("should add menu item to empty menu", function () {
        const componentName = "NewComponent";
        const res = (0, addLinkToMenu_1.addLinkToMenu)(`<Menu></Menu>`, route, componentName);
        (0, chai_1.expect)(res).to.contain(`<MenuItemSecured name="NewComponent" to="/route" primaryText="routes.NewComponent" leftIcon={<WebAsset />} />`);
        (0, chai_1.expect)(res).to.contain(`import { MenuItemSecured } from "../../core/security/components/MenuItemSecured";`);
    });
    it("should do nothing if menu item already in menu", function () {
        const componentName = "OldComponent";
        const res = (0, addLinkToMenu_1.addLinkToMenu)(MENU_INPUT, route, componentName);
        (0, chai_1.expect)(res).to.eq(MENU_INPUT);
    });
    it("should fail for incorrect input", function () {
        const componentName = "NewComponent";
        (0, chai_1.expect)(addLinkToMenu_1.addLinkToMenu.bind(undefined, `Not jsx`, componentName)).to.throw();
        const emptyJsx = '';
        (0, chai_1.expect)(addLinkToMenu_1.addLinkToMenu.bind(undefined, emptyJsx, componentName)).to.throw();
    });
    it("should fail if Menu tag not found", function () {
        const componentName = "NewComponent";
        (0, chai_1.expect)(addLinkToMenu_1.addLinkToMenu.bind(undefined, `<NotMenuTag></NotMenuTag>`, componentName))
            .to.throw();
    });
});
//# sourceMappingURL=addLinkToMenu.test.js.map