"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addResourceToMenu = void 0;
const tslib_1 = require("tslib");
const jscodeshift_1 = tslib_1.__importDefault(require("jscodeshift"));
const getMenuTagChildren_1 = require("./getMenuTagChildren");
const toSource_1 = require("../jsCodeShift/toSource");
const insertSpecifierImport_1 = require("../jsCodeShift/insertSpecifierImport");
/**
 * Add resource to menu. If line with such resource already exist - do nothing.
 * Example of added line `<MenuResourceItemSecured name="OwnerDTO" />`;
 *
 * @param menuInput jsx menu as test
 * @param resourceName name of resource to be added in menu
 */
function addResourceToMenu(menuInput, resourceName) {
    const tsxParser = jscodeshift_1.default.withParser("tsx");
    const appMenuAST = tsxParser(menuInput);
    const isItemAlreadyExist = appMenuAST
        .findJSXElements("MenuResourceItemSecured")
        .nodes()
        .some((el) => {
        const openingEl = el.openingElement;
        // looking for MenuItem like `<MenuItemSecured  to="/BlankComponent" primaryText="BlankComponent" />`,
        // where BlankComponent is componentName
        return openingEl?.attributes?.some((attr) => attr.name.name === "name" && attr.value.value === resourceName);
    });
    if (!isItemAlreadyExist) {
        const resourceTag = `<MenuResourceItemSecured name="${resourceName}" />`;
        (0, getMenuTagChildren_1.getMenuTagChildren)(appMenuAST).push(jscodeshift_1.default.stringLiteral(resourceTag));
        (0, insertSpecifierImport_1.insertSpecifierImport)(appMenuAST, "MenuResourceItemSecured", "../../core/security/components/MenuResourceItemSecured");
        console.log(`addResourceToMenu: resource item added to menu\n ${resourceTag}`);
    }
    else {
        console.log(`addResourceToMenu: skip adding resource item to menu, item ${resourceName} already exist`);
    }
    return (0, toSource_1.toSource)(appMenuAST);
}
exports.addResourceToMenu = addResourceToMenu;
//# sourceMappingURL=addResourceToMenu.js.map