"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const addResourceToMenu_1 = require("./addResourceToMenu");
const chai_1 = require("chai");
describe("addResourceToMenu", () => {
    const MENU_INPUT = `
    <Menu>
      <Menu.DashboardItem />
      <MenuResourceItemSecured name="OwnerDTO" />
      <MenuResourceItemSecured name="PetTypeDTO" />
    </Menu>
  `;
    it("should add resource item to menu, if item not exist", function () {
        const resourceName = "NewEntityDTO";
        const res = (0, addResourceToMenu_1.addResourceToMenu)(MENU_INPUT, resourceName);
        (0, chai_1.expect)(res).to.contain(`<MenuResourceItemSecured name="NewEntityDTO" />`);
        (0, chai_1.expect)(res).to.contain(`import { MenuResourceItemSecured } from "../../core/security/components/MenuResourceItemSecured";`);
    });
    it("should add resource item to empty menu", function () {
        const resourceName = "NewEntityDTO";
        const res = (0, addResourceToMenu_1.addResourceToMenu)(`<Menu></Menu>`, resourceName);
        (0, chai_1.expect)(res).to.contain(`<MenuResourceItemSecured name="NewEntityDTO" />`);
        (0, chai_1.expect)(res).to.contain(`import { MenuResourceItemSecured } from "../../core/security/components/MenuResourceItemSecured";`);
    });
    // TODO
    xit("should add resource item to empty self-closing menu", function () {
        const resourceName = "NewEntityDTO";
        const res = (0, addResourceToMenu_1.addResourceToMenu)(`<Menu/>`, resourceName);
        (0, chai_1.expect)(res).to.contain(`<MenuResourceItemSecured name="NewEntityDTO" />`);
    });
    it("should do nothing if resource item already in menu", function () {
        const resourceName = "OwnerDTO";
        const res = (0, addResourceToMenu_1.addResourceToMenu)(MENU_INPUT, resourceName);
        (0, chai_1.expect)(res).to.eq(MENU_INPUT);
    });
    it("should fail for incorrect input", function () {
        const resourceName = "OwnerDTO";
        (0, chai_1.expect)(addResourceToMenu_1.addResourceToMenu.bind(undefined, `Not jsx`, resourceName)).to.throw();
        const emptyJsx = '';
        (0, chai_1.expect)(addResourceToMenu_1.addResourceToMenu.bind(undefined, emptyJsx, resourceName)).to.throw();
    });
    it("should fail if Menu tag not found", function () {
        const resourceName = "OwnerDTO";
        (0, chai_1.expect)(addResourceToMenu_1.addResourceToMenu.bind(undefined, `<NotMenuTag></NotMenuTag>`, resourceName)).to.throw();
    });
});
//# sourceMappingURL=addResourceToMenu.test.js.map