"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addScreenToAdminUi = void 0;
const tslib_1 = require("tslib");
const j = tslib_1.__importStar(require("jscodeshift"));
const recordRepresentationFunctionName_1 = require("../../../../../generators/react-admin/common/recordRepresentation/recordRepresentationFunctionName");
const insertSpecifierImport_1 = require("../jsCodeShift/insertSpecifierImport");
const parseTs_1 = require("../../../../util/parseTs");
const getAdminUiTagChildren_1 = require("./getAdminUiTagChildren");
function addScreenToAdminUi(appTsxInput, resourceName, screenName, screenType, screenImportPath, recordRepresentationFunctionImport) {
    // custom TS parser required
    const appAST = (0, parseTs_1.parseTs)(appTsxInput);
    const adminUi = appAST.findJSXElements("AdminUI");
    const children = (0, getAdminUiTagChildren_1.getAdminUiTagChildren)(adminUi);
    // try to find already existed <ResourceSecured name={resourceName}> tag in AdminUI
    const resourceItem = children
        .filter(el => el.type === j.JSXElement.toString())
        .find(el => {
        const openingEl = el.openingElement;
        return openingEl?.name?.name === "ResourceSecured" &&
            openingEl?.attributes?.some((attr) => attr.name?.name === "name" && attr.value?.value === resourceName);
    });
    if (resourceItem != null) {
        console.log(`addScreenToAdminUi: skip adding resource item to AdminUI tag, item ${resourceName} already exist`);
        const openingEl = resourceItem.openingElement;
        // try to find attribute, named as screenType in Resource tag
        const screenAttr = openingEl?.attributes?.find((attr) => attr.name.name === screenType);
        if (screenAttr != null) {
            // screen with such type already exist in Resource - overwrite attr value
            screenAttr.value = j.jsxExpressionContainer(j.jsxIdentifier(screenName));
            console.log(`addScreenToAdminUi: update attribute value to ${screenType}={ ${screenName} }'` +
                ` in ${resourceName} resource tag`);
        }
        else {
            // attribute for such screen type doesn't exist in Resource tag
            // add attribute `screenType={screenName}` to Resource tag
            // result example `<ResourceSecured create={ PetCreateAdvanced } />`
            const newScreenAttr = j.jsxAttribute(j.jsxIdentifier(screenType), j.jsxExpressionContainer(j.jsxIdentifier(screenName)));
            openingEl.attributes.push(newScreenAttr);
            console.log(`addScreenToAdminUi: attribute '${screenType}={ ${screenName} }' ` +
                `added to ${resourceName} resource tag`);
        }
    }
    else {
        const resourceItemTag = createResourceTag(resourceName, screenType, screenName);
        children?.push(j.stringLiteral(resourceItemTag));
        console.log(`addScreenToAdminUi: adding item to AdminUI tag \n${resourceItemTag} `);
    }
    (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, "ResourceSecured", "../core/security/components/ResourceSecured");
    (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, screenName, screenImportPath);
    const recordRepFunctionName = (0, recordRepresentationFunctionName_1.recordRepresentationFunctionName)(resourceName);
    (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, recordRepFunctionName, recordRepresentationFunctionImport);
    return appAST.toSource();
}
exports.addScreenToAdminUi = addScreenToAdminUi;
function createResourceTag(resourceName, screenType, screenName) {
    return `` +
        `<ResourceSecured name="${resourceName}"` +
        ` ${screenType}={${screenName}} recordRepresentation={${(0, recordRepresentationFunctionName_1.recordRepresentationFunctionName)(resourceName)}} />`;
}
//# sourceMappingURL=addScreenToAdminUi.js.map