"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceStringValue = exports.replaceStringValueInFile = void 0;
const tslib_1 = require("tslib");
const jscodeshift_1 = tslib_1.__importDefault(require("jscodeshift"));
const ReplacementTargetNotFoundError_1 = require("./ReplacementTargetNotFoundError");
const toSource_1 = require("../../jsCodeShift/toSource");
async function replaceStringValueInFile(gen, file, variableName, newValue) {
    const filePath = gen.destinationPath(file);
    const source = gen.fs.read(filePath);
    const tsParser = jscodeshift_1.default.withParser('ts');
    const ast = tsParser(source);
    try {
        replaceStringValue(ast, variableName, newValue);
    }
    catch (error) {
        if (error instanceof ReplacementTargetNotFoundError_1.ReplacementTargetNotFoundError) {
            gen.log(`WARNING: Was trying to change ${variableName} in "${file}" to ${newValue}, but this file does not contain this variable. This may break the application.`);
            return;
        }
    }
    const output = (0, toSource_1.toSource)(ast);
    await gen.fs.write(filePath, output);
}
exports.replaceStringValueInFile = replaceStringValueInFile;
function replaceStringValue(ast, variableName, newValue) {
    const loginUriStringValue = ast
        .findVariableDeclarators(variableName)
        .find(jscodeshift_1.default.StringLiteral);
    if (loginUriStringValue.length === 0) {
        throw new ReplacementTargetNotFoundError_1.ReplacementTargetNotFoundError();
    }
    loginUriStringValue
        .replaceWith(jscodeshift_1.default.stringLiteral(newValue));
}
exports.replaceStringValue = replaceStringValue;
//# sourceMappingURL=replaceStringValue.js.map