"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const jscodeshift_1 = tslib_1.__importDefault(require("jscodeshift"));
const replaceStringValue_1 = require("./replaceStringValue");
const ReplacementTargetNotFoundError_1 = require("./ReplacementTargetNotFoundError");
const toSource_1 = require("../../jsCodeShift/toSource");
const tsParser = jscodeshift_1.default.withParser('ts');
describe('replaceStringValue()', () => {
    it('replaces variable value in AST', () => {
        const ast = tsParser(envConfig);
        (0, replaceStringValue_1.replaceStringValue)(ast, 'LOGIN_URI', '/oauth2/authorize');
        (0, chai_1.expect)((0, toSource_1.toSource)(ast)).to.eq(envConfigModified);
        const ast2 = tsParser(viteConfig);
        (0, replaceStringValue_1.replaceStringValue)(ast2, 'LOGIN_BASE_URL', 'oauth2');
        (0, chai_1.expect)((0, toSource_1.toSource)(ast2)).to.eq(viteConfigModified);
    });
    it('throws exception when it cannot find the variable', () => {
        const ast = tsParser(envConfigFailing);
        (0, chai_1.expect)(replaceStringValue_1.replaceStringValue.bind(undefined, ast, 'LOGIN_URI', '/oauth2/authorize')).to.throw(ReplacementTargetNotFoundError_1.ReplacementTargetNotFoundError);
    });
});
const envConfigFailing = `
export const GRAPHQL_URI = import.meta.env.VITE_GRAPHQL_URI ?? "/graphql";
export const LOGOUT_URI = import.meta.env.VITE_LOGOUT_URI ?? "/logout";
export const REQUEST_SAME_ORIGIN =
  import.meta.env.VITE_REQUEST_SAME_ORIGIN ?? true;
export const DEV_LOGIN = import.meta.env.VITE_DEV_LOGIN ?? "admin";
export const DEV_PASSWORD = import.meta.env.VITE_DEV_PASSWORD ?? "admin";
`;
const envConfig = `
export const GRAPHQL_URI = import.meta.env.VITE_GRAPHQL_URI ?? "/graphql";
export const LOGIN_URI = import.meta.env.VITE_LOGIN_URI ?? "/login";
export const LOGOUT_URI = import.meta.env.VITE_LOGOUT_URI ?? "/logout";
export const REQUEST_SAME_ORIGIN =
  import.meta.env.VITE_REQUEST_SAME_ORIGIN ?? true;
export const DEV_LOGIN = import.meta.env.VITE_DEV_LOGIN ?? "admin";
export const DEV_PASSWORD = import.meta.env.VITE_DEV_PASSWORD ?? "admin";
`;
const envConfigModified = `
export const GRAPHQL_URI = import.meta.env.VITE_GRAPHQL_URI ?? "/graphql";
export const LOGIN_URI = import.meta.env.VITE_LOGIN_URI ?? "/oauth2/authorize";
export const LOGOUT_URI = import.meta.env.VITE_LOGOUT_URI ?? "/logout";
export const REQUEST_SAME_ORIGIN =
  import.meta.env.VITE_REQUEST_SAME_ORIGIN ?? true;
export const DEV_LOGIN = import.meta.env.VITE_DEV_LOGIN ?? "admin";
export const DEV_PASSWORD = import.meta.env.VITE_DEV_PASSWORD ?? "admin";
`;
const viteConfig = `
import { defineConfig } from "vite";
import react from "@vitejs/plugin-react";

const PORT = "8080";
const SERVER_URL = "http://localhost";
const LOGIN_BASE_URL = "login";

export default defineConfig({
  assetsInclude: ["**/*.graphql"],
  plugins: [react()],
  server: {
    proxy: {
      [\`^/(graphql|\${LOGIN_BASE_URL}|logout)\`]: \`\${SERVER_URL}:\${PORT}\`,
    }
  }
});
`;
const viteConfigModified = `
import { defineConfig } from "vite";
import react from "@vitejs/plugin-react";

const PORT = "8080";
const SERVER_URL = "http://localhost";
const LOGIN_BASE_URL = "oauth2";

export default defineConfig({
  assetsInclude: ["**/*.graphql"],
  plugins: [react()],
  server: {
    proxy: {
      [\`^/(graphql|\${LOGIN_BASE_URL}|logout)\`]: \`\${SERVER_URL}:\${PORT}\`,
    }
  }
});
`;
//# sourceMappingURL=replaceStringValue.test.js.map