"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.launchCli = exports.createCli = exports.createAndLaunchCli = exports.ownVersion = void 0;
const tslib_1 = require("tslib");
/* istanbul ignore file */ //todo not sure how to test and cover this
const init_1 = require("./init");
const commander_1 = require("commander");
const list_1 = require("./list");
const cli_options_1 = require("./common/cli-options");
const path = tslib_1.__importStar(require("path"));
exports.ownVersion = require('../package').version;
function createAndLaunchCli() {
    const { program } = require('commander');
    // Add options that configure which generators to use
    program
        .addOption(new commander_1.Option('--custom-generator-paths <paths...>', 'Use custom generators from the filesystem.'))
        .allowUnknownOption(true); // Otherwise program.parse below will fail when any other (command-specific) options are provided. We set allowUnknownOption back to false once we know the full list of options.
    const { customGeneratorPaths } = program.parse().opts();
    const expandRelativePath = (p) => path.resolve(p);
    const clients = (0, init_1.collectClients)(undefined, {
        customGeneratorPaths: customGeneratorPaths?.map(expandRelativePath),
    });
    const cli = createCli(exports.ownVersion, clients, undefined, undefined, program);
    launchCli(cli);
}
exports.createAndLaunchCli = createAndLaunchCli;
function createCli(version, clients, customClientNames, customClientsBaseDir, program = require('commander')) {
    program.version(version, '-v, --version')
        .usage('[command] [options]');
    program
        .command('list')
        .description('List all available clients and their clients')
        .option('-s, --save [saveTo]', 'Save information about clients ')
        .action((cmd) => (0, list_1.exportList)(clients, cmd));
    clients.forEach(client => {
        client.generators.forEach(function (generator) {
            const generationCommand = program
                .command(`${client.name}:${generator.name}`)
                .description(`Generates ${client.name} ${generator.name}`);
            (0, cli_options_1.extractAvailableOptions)(generator.options).forEach(({ pattern, description }) => {
                generationCommand.option(pattern, description);
            });
            program.allowUnknownOption(false);
            generationCommand.action(function (cmd) {
                return (0, init_1.generate)(generator.path, (0, cli_options_1.pickOptions)(cmd, generator.options), generator.templateOverride);
            });
        });
    });
    return program;
}
exports.createCli = createCli;
function launchCli(program) {
    program.parse(process.argv); // invokes provided command
    if (!process.argv.slice(2).length) {
        program.outputHelp();
    }
}
exports.launchCli = launchCli;
//# sourceMappingURL=cli.js.map