"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeSecret = exports.getOpenedCubaProjects = exports.exportProjectModel = exports.ERR_STUDIO_NOT_CONNECTED = void 0;
const tslib_1 = require("tslib");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const DEFAULT_INTEGRATION_PORT = 48561;
exports.ERR_STUDIO_NOT_CONNECTED = '' +
    'Can\'t establish connection to CUBA Studio. Please open CUBA Studio Intellij and tick \'Enable Integration\' checkbox. ' +
    'Or provide path to project model json file as cli parameter --model';
async function exportProjectModel(projectLocationHash, dest, port = DEFAULT_INTEGRATION_PORT) {
    try {
        const params = `exportModelProjectDest=${encodeURIComponent(dest)}&exportModelProjectHash=${projectLocationHash}`;
        return await (0, node_fetch_1.default)(`http://localhost:${port}/?${params}`);
    }
    catch {
        throw Error(exports.ERR_STUDIO_NOT_CONNECTED);
    }
}
exports.exportProjectModel = exportProjectModel;
async function getOpenedCubaProjects(port = DEFAULT_INTEGRATION_PORT) {
    try {
        const resp = await (0, node_fetch_1.default)(`http://localhost:${port}/?printCubaProjects`);
        return resp.json();
    }
    catch {
        return null;
    }
}
exports.getOpenedCubaProjects = getOpenedCubaProjects;
function normalizeSecret(restClientSecret) {
    return restClientSecret.replace(/{.*}/, '');
}
exports.normalizeSecret = normalizeSecret;
//# sourceMappingURL=studio-integration.js.map