import Base from "yeoman-generator";
/**
 * Remove illegal symbols and normalize class name by standard js notation.
 *
 * @param {string} elementName 'my-app-custom' | 'myAppCustom' | 'my app custom'
 * @returns {string} class name MyAppCustom
 */
export declare const elementNameToClass: (elementName: string) => string;
export declare const capitalizeFirst: (part: string) => string;
export declare const unCapitalizeFirst: (part: string) => string;
export declare const splitByCapitalLetter: (word: string) => string;
/**
 * Removes 'Dto' and 'DTO' strings from the end of `word`.
 * @param word
 */
export declare const removeDtoSuffixFromEntityName: (word: string) => string;
export declare function convertToUnixPath(input: string): string;
/**
 * Convert java class fully qualified name to compilable TS class name
 *
 * @param fqn java class fqn
 */
export declare function fqnToName(fqn: string): string;
export declare function isBlank(str: string | undefined): boolean;
/**
 *
 * Converts any type of paths (with all types of slashes) to posix path, which is used
 * in typescript imports. This type of path is not depends on current OS (Windows\Linux)
 * and always use forward slashes.
 *
 * Returned path contains only forward slashes and no backward slashes,
 * and has a trailing forward slash.
 *
 * Note, `addLeadingSlash = false` introduced for backward compatibility with antd version of generators.
 * This parameter should be removed after finish antd version support.
 * In react-admin generators this method should be used with `addLeadingSlash = true` only.
 *
 * @param relPath
 * @param addLeadingSlash if `true` - prepend `./` for paths, which are not start from `.`
 */
export declare function normalizeImportRelativePath(relPath: string | undefined, addLeadingSlash?: boolean): string;
/**
 * The preferable method of throwing an error in Yeoman is using Environment.error() method.
 * It will prevent execution of the subsequent code, however, TypeScript compiler doesn't know about that.
 * Therefore, using Environment.error() in a function that returns a value will require e.g. throwing an error manually
 * or returning an empty value.
 * In such cases this helper function can be used. It returns `never`, which means that compiler won't consider
 * the code after this function reachable.
 *
 * @param generator
 * @param error
 */
export declare function throwError(generator: Pick<Base, 'env'>, error: string): never;
export declare function read(filePath: string): string;
