"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const utils_1 = require("./utils");
const assert_1 = tslib_1.__importDefault(require("assert"));
describe('utils', () => {
    it("elementNameToClass", () => {
        assert_1.default.strictEqual((0, utils_1.elementNameToClass)('my-custom-el'), 'MyCustomEl');
        assert_1.default.strictEqual((0, utils_1.elementNameToClass)('x-f'), 'XF');
        assert_1.default.strictEqual((0, utils_1.elementNameToClass)('myCustomEl'), 'MyCustomEl');
        assert_1.default.strictEqual((0, utils_1.elementNameToClass)('my custom El'), 'MyCustomEl');
        assert_1.default.strictEqual((0, utils_1.elementNameToClass)('  my   veryCustom  El   '), 'MyVeryCustomEl');
        assert_1.default.strictEqual((0, utils_1.elementNameToClass)('~!@#%^&*()_+the Cla$$'), '_theCla$$');
    });
    it(utils_1.convertToUnixPath.name, () => {
        assert_1.default.strictEqual((0, utils_1.convertToUnixPath)('.\\some\\path'), './some/path');
    });
    it('should convert fqn name to valid TS class name ', () => {
        assert_1.default.strictEqual((0, utils_1.fqnToName)('com.company.mpg.entity.CarType'), 'com_company_mpg_entity_CarType');
        assert_1.default.strictEqual((0, utils_1.fqnToName)(''), '');
    });
    it('should split string by capital letter', () => {
        (0, chai_1.expect)((0, utils_1.splitByCapitalLetter)('splitByCapital')).eq('split By Capital');
        (0, chai_1.expect)((0, utils_1.splitByCapitalLetter)('SplitByCapital')).eq('Split By Capital');
        (0, chai_1.expect)((0, utils_1.splitByCapitalLetter)('split123It')).eq('split123 It');
        (0, chai_1.expect)((0, utils_1.splitByCapitalLetter)('split$It')).eq('split$ It');
        (0, chai_1.expect)((0, utils_1.splitByCapitalLetter)('split_It')).eq('split_ It');
    });
});
describe('normalizeImportRelativePath()', () => {
    it('Replaces the backslashes in the provided path with forward slashes', () => {
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)('..\\..\\')).to.equal('../../');
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)('..\\..')).to.equal('../../');
    });
    it('Adds a trailing slash if it is missing', () => {
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)('../..')).to.equal('../../');
    });
    it('Does not add an additional trailing slash if already present', () => {
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)('../../')).to.equal('../../');
    });
    it('should normalize relative path', () => {
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("   ")).eq("");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)(undefined)).eq("");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("")).eq("");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("..")).eq("../");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("../")).eq("../");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("../..")).eq("../../");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("../../")).eq("../../");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)(".")).eq("./");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("./")).eq("./");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("./../")).eq("../");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("a\\b\\c")).eq("a/b/c/");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("a\\b\\c\\")).eq("a/b/c/");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("a\\b\\c\\", true)).eq("./a/b/c/");
        (0, chai_1.expect)((0, utils_1.normalizeImportRelativePath)("..")).eq("../");
    });
});
//# sourceMappingURL=utils.test.js.map