"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeAddonBlank = void 0;
const tslib_1 = require("tslib");
const addCustomRouteToAdminUi_1 = require("../../../building-blocks/stages/writing/pieces/screen/addCustomRouteToAdminUi");
const mvp_1 = require("../../../building-blocks/stages/writing/pieces/mvp/mvp");
const generatorPaths_1 = require("../common/generatorPaths");
const writeMenuItemToMenu_1 = require("../common/writeMenuItemToMenu");
const path_1 = tslib_1.__importDefault(require("path"));
const mergeI18nMessagesWithLocaleFile_1 = require("../common/i18n/mergeI18nMessagesWithLocaleFile");
const change_case_1 = require("change-case");
const node_fs_1 = tslib_1.__importDefault(require("node:fs"));
const appendAddonComponentExportsToIndexTs_1 = require("../appendAddonComponentExportsToIndexTs");
async function writeAddonBlank(templateModel, gen) {
    await (0, mvp_1.writeAmplicodeComponent)(templateModel, gen, path_1.default.join(__dirname, 'template', 'BlankScreen.tsx.ejs'), false, false, false);
    const { componentName, route, shouldAddToMenu, relDirShift } = templateModel;
    const addonPaths = (0, generatorPaths_1.deriveAddonScreenPaths)(gen.destinationRoot(), relDirShift);
    const metadataObj = JSON.parse(node_fs_1.default.readFileSync(addonPaths.metadataFilePath, "utf-8"));
    const addonPackageName = JSON.parse(node_fs_1.default.readFileSync(addonPaths.addonPackageJsonFilePath, "utf-8")).name;
    // Add menu item
    if (shouldAddToMenu) {
        (0, writeMenuItemToMenu_1.writeMenuItemToMenu)(gen, addonPaths.sampleAppMenuFilePath, route, componentName);
        metadataObj.menuItems.push({
            type: "Menu.Item",
            name: componentName,
            to: route,
            primaryText: `pages.${componentName}`
        });
    }
    const appTsxFilePath = addonPaths.sampleAppAppFilePath;
    if (!gen.fs.exists(appTsxFilePath)) {
        gen.log(`Unable to add screen to AdminUI, App.tsx file not found in path '${appTsxFilePath}'`);
    }
    else {
        const appContents = gen.fs.read(appTsxFilePath);
        const appTransformed = (0, addCustomRouteToAdminUi_1.addCustomRouteToAdminUi)(appContents, componentName, addonPackageName, route);
        // Add Route to <AdminUI> in App.tsx
        gen.fs.write(appTsxFilePath, appTransformed);
        // add "customRoutes" to metadata
        metadataObj.customRoutes.push({
            path: route,
            element: componentName
        });
        // write metadataObj to file
        node_fs_1.default.writeFileSync(addonPaths.metadataFilePath, JSON.stringify(metadataObj, null, "  "));
        // add export of component in addon `index.ts`
        (0, appendAddonComponentExportsToIndexTs_1.appendAddonComponentExportsToIndexTs)(addonPaths, [componentName], null, []);
        await (0, mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFile)(addonPaths.addonI18NPath, "en", {
            pages: {
                [componentName]: (0, change_case_1.capitalCase)(componentName)
            }
        }, "en");
    }
}
exports.writeAddonBlank = writeAddonBlank;
//# sourceMappingURL=write.js.map