"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeAddonEntityList = void 0;
const tslib_1 = require("tslib");
const mvp_1 = require("../../../building-blocks/stages/writing/pieces/mvp/mvp");
const writeScreenToAdminUi_1 = require("../common/writeScreenToAdminUi");
const generatorPaths_1 = require("../common/generatorPaths");
const node_path_1 = tslib_1.__importDefault(require("node:path"));
const mergeI18nMessagesWithLocaleFile_1 = require("../common/i18n/mergeI18nMessagesWithLocaleFile");
const node_fs_1 = tslib_1.__importDefault(require("node:fs"));
const writeResourceToMenu_1 = require("../common/writeResourceToMenu");
const writeRecordRepresentationFunction_1 = require("../common/recordRepresentation/writeRecordRepresentationFunction");
const writeRecordRepresentationFunctionsForRelations_1 = require("../common/recordRepresentation/writeRecordRepresentationFunctionsForRelations");
const change_case_1 = require("change-case");
const recordRepresentationFunctionName_1 = require("../common/recordRepresentation/recordRepresentationFunctionName");
const appendAddonComponentExportsToIndexTs_1 = require("../appendAddonComponentExportsToIndexTs");
const filterFileAttributes_1 = require("../common/filterFileAttributes");
const writeAddonSampleAppI18nFile_1 = require("../common/i18n/writeAddonSampleAppI18nFile");
async function writeAddonEntityList(templateModel, gen) {
    const { relDirShift, entityName, componentName, i18nMessages, attributes, allAttributes } = templateModel;
    // Write screen component
    await (0, mvp_1.writeAmplicodeComponent)({ ...templateModel, attributes: (0, filterFileAttributes_1.filterFileAttributes)(templateModel.attributes) }, gen, node_path_1.default.join(__dirname, 'template', `ListAdvanced.tsx.ejs`), false, false, false);
    const addonPaths = (0, generatorPaths_1.deriveAddonScreenPaths)(gen.destinationRoot(), relDirShift);
    const metadataObj = JSON.parse(node_fs_1.default.readFileSync(addonPaths.metadataFilePath, "utf-8"));
    const addonPackageName = JSON.parse(node_fs_1.default.readFileSync(addonPaths.addonPackageJsonFilePath, "utf-8")).name;
    // Add menu item
    (0, writeResourceToMenu_1.writeResourceToMenu)(gen, addonPaths.sampleAppSrcPath, entityName);
    metadataObj.menuItems.push({
        type: "Menu.ResourceItem",
        name: componentName,
    });
    // Add screen to <AdminUI>
    // in App.tsx import of screen and record reps should be not relative, but from addon package
    (0, writeScreenToAdminUi_1.writeScreenToAdminUi)(gen, {
        appTsxPath: addonPaths.sampleAppAppFilePath,
        screenImportPath: addonPackageName,
        recordRepresentationImport: addonPackageName
    }, entityName, componentName, "list");
    const metadataResource = metadataObj.resources
        .find(resItem => resItem.name === entityName);
    if (metadataResource != null) {
        metadataResource.list = componentName;
    }
    else {
        metadataObj.resources.push({
            name: entityName,
            label: (0, change_case_1.capitalCase)(entityName),
            recordRepresentation: (0, recordRepresentationFunctionName_1.recordRepresentationFunctionName)(entityName),
            list: componentName,
        });
    }
    // write metadataObj to file
    node_fs_1.default.writeFileSync(addonPaths.metadataFilePath, JSON.stringify(metadataObj, null, "  "));
    // add export of component in addon `index.ts`
    (0, appendAddonComponentExportsToIndexTs_1.appendAddonComponentExportsToIndexTs)(addonPaths, [componentName], entityName, attributes);
    (0, writeRecordRepresentationFunction_1.writeRecordRepresentationFunction)({
        gen,
        entityName,
        attributes: allAttributes,
        dirShift: relDirShift
    });
    (0, writeRecordRepresentationFunctionsForRelations_1.writeRecordRepresentationFunctionsForRelations)(gen, attributes, relDirShift);
    await (0, mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFile)(addonPaths.addonI18NPath, 'en', i18nMessages, "en");
    (0, writeAddonSampleAppI18nFile_1.writeAddonSampleAppI18nFile)(addonPaths.sampleAppI18nFilePath, addonPackageName, metadataObj.addonBackendName);
}
exports.writeAddonEntityList = writeAddonEntityList;
//# sourceMappingURL=write.js.map