"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeAuthFormLogin = void 0;
const tslib_1 = require("tslib");
const replaceStringValue_1 = require("../../../building-blocks/stages/writing/pieces/source-utils/variables/replaceStringValue");
const appendCode_1 = require("../../../building-blocks/stages/writing/pieces/source-utils/appendCode");
const addEnvVar_1 = require("../../../building-blocks/stages/writing/pieces/source-utils/variables/addEnvVar");
const path_1 = tslib_1.__importDefault(require("path"));
const writeAppTemplate_1 = require("../common/writeAppTemplate");
const authConfig_1 = require("../common/auth/authConfig");
async function writeAuthFormLogin(templateModel, gen) {
    // write files from 'app' generator template folder
    await (0, writeAppTemplate_1.writeAppTemplate)(gen, path_1.default.join('src', 'index.tsx'));
    await (0, writeAppTemplate_1.writeAppTemplate)(gen, path_1.default.join('src', 'authProvider', 'authProvider.ts'));
    await (0, writeAppTemplate_1.writeAppTemplate)(gen, path_1.default.join('src', 'authProvider', 'useAuthProvider.ts'));
    await (0, writeAppTemplate_1.writeAppTemplate)(gen, path_1.default.join('src', 'core', 'apollo', 'client.ts'));
    // Add login/logout endpoints
    await (0, replaceStringValue_1.replaceStringValueInFile)(gen, 'vite.config.ts', 'AMPLICODE_ENDPOINTS', authConfig_1.AUTH_FORM_LOGIN_ENDPOINTS);
    // Add environment variables
    const envVarConfig = `export const LOGIN_URI = import.meta.env.VITE_LOGIN_URI ?? "/login";
  export const LOGOUT_URI = import.meta.env.VITE_LOGOUT_URI ?? "/logout";
  export const REQUEST_SAME_ORIGIN =
    import.meta.env.VITE_REQUEST_SAME_ORIGIN ?? true;
  export const DEV_LOGIN = import.meta.env.VITE_DEV_LOGIN ?? "admin";
  export const DEV_PASSWORD = import.meta.env.VITE_DEV_PASSWORD ?? "admin";`;
    await (0, appendCode_1.appendCodeInFile)(gen, 'src/config.ts', envVarConfig);
    for (const fileName of ['.env.development', '.env.production']) {
        await (0, addEnvVar_1.addEnvVarInFile)(gen, fileName, 'VITE_LOGIN_URI', '/login');
        await (0, addEnvVar_1.addEnvVarInFile)(gen, fileName, 'VITE_LOGOUT_URI', '/logout');
        await (0, addEnvVar_1.addEnvVarInFile)(gen, fileName, 'VITE_REQUEST_SAME_ORIGIN', 'true');
        await (0, addEnvVar_1.addEnvVarInFile)(gen, fileName, 'VITE_DEV_LOGIN', 'admin');
        await (0, addEnvVar_1.addEnvVarInFile)(gen, fileName, 'VITE_DEV_PASSWORD', 'admin');
    }
}
exports.writeAuthFormLogin = writeAuthFormLogin;
//# sourceMappingURL=write.js.map