"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeBlank = void 0;
const tslib_1 = require("tslib");
const addCustomRouteToAdminUi_1 = require("../../../building-blocks/stages/writing/pieces/screen/addCustomRouteToAdminUi");
const mvp_1 = require("../../../building-blocks/stages/writing/pieces/mvp/mvp");
const generatorPaths_1 = require("../common/generatorPaths");
const writeMenuItemToMenu_1 = require("../common/writeMenuItemToMenu");
const path_1 = tslib_1.__importDefault(require("path"));
const mergeI18nMessagesWithLocaleFile_1 = require("../common/i18n/mergeI18nMessagesWithLocaleFile");
const change_case_1 = require("change-case");
async function writeBlank(templateModel, gen) {
    await (0, mvp_1.writeAmplicodeComponent)(templateModel, gen, path_1.default.join(__dirname, 'template', 'BlankScreen.tsx.ejs'), false, false, !templateModel.skipTestGeneration);
    const screenPaths = (0, generatorPaths_1.deriveScreenPaths)(gen.destinationRoot(), templateModel.relDirShift);
    // Add menu item
    if (templateModel.shouldAddToMenu) {
        (0, writeMenuItemToMenu_1.writeMenuItemToMenu)(gen, screenPaths.menuTsxPath, templateModel.route, templateModel.componentName);
    }
    const appTsxFilePath = screenPaths.appTsxPath;
    if (!gen.fs.exists(appTsxFilePath)) {
        gen.log(`Unable to add screen to AdminUI, App.tsx file not found in path '${appTsxFilePath}'`);
    }
    else {
        const appContents = gen.fs.read(appTsxFilePath);
        const appTransformed = (0, addCustomRouteToAdminUi_1.addCustomRouteToAdminUi)(appContents, templateModel.componentName, screenPaths.relativeDestPath, templateModel.route);
        // Add Route to <AdminUI> in App.tsx
        gen.fs.write(appTsxFilePath, appTransformed);
        await (0, mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFile)(screenPaths.localeMessagesPath, 'en', { pages: {
                [templateModel.componentName]: (0, change_case_1.capitalCase)(templateModel.componentName)
            } });
        gen.log(`Custom Route '${templateModel.componentName}' added to AdminUI tag in '${appTsxFilePath}'`);
    }
}
exports.writeBlank = writeBlank;
//# sourceMappingURL=write.js.map