"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.raResetAuth = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const removeEnvVarInFile_1 = require("./removeEnvVarInFile");
const removeVarExportInFile_1 = require("./removeVarExportInFile");
const replaceStringValueInFile_1 = require("./replaceStringValueInFile");
const npmDeps_1 = require("./npmDeps");
const auth_oidc_keycloak_1 = require("../../auth-oidc-keycloak");
const authConfig_1 = require("./authConfig");
function raResetAuth(dest) {
    console.log("raResetAuth: dest ", dest);
    // delete files
    deleteFileSync(path_1.default.join(dest, "src", "authProvider"));
    deleteFileSync(path_1.default.join(dest, "src", "core", "apollo"));
    // todo move oidc files in `oidc` sub folder and cleanup this sub folder
    deleteFileSync(path_1.default.join(dest, "src", "core", "security", "oidcConfig.ts"));
    deleteFileSync(path_1.default.join(dest, "src", "core", "security", "OidcKeycloakAuthProvider.tsx"));
    deleteFileSync(path_1.default.join(dest, "src", "index.tsx"));
    // remove env vars
    const envVarsToRemove = ['VITE_LOGIN_URI', 'VITE_LOGOUT_URI', 'VITE_REQUEST_SAME_ORIGIN', 'VITE_DEV_LOGIN', 'VITE_DEV_PASSWORD',
        'VITE_OIDC_CONFIG_SCOPE', 'VITE_OIDC_CONFIG_CLIENT_ID', 'VITE_OIDC_CONFIG_AUTHORITY'];
    (0, removeEnvVarInFile_1.removeEnvVarInFile)(path_1.default.join(dest, './.env.development'), envVarsToRemove);
    (0, removeEnvVarInFile_1.removeEnvVarInFile)(path_1.default.join(dest, './.env.production'), envVarsToRemove);
    const varExportsToRemove = ['LOGIN_URI', 'LOGOUT_URI', 'DEV_PASSWORD', 'DEV_LOGIN', 'REQUEST_SAME_ORIGIN'];
    // - src/config.ts
    (0, removeVarExportInFile_1.removeVarExportInFile)(path_1.default.join(dest, './src/config.ts'), varExportsToRemove);
    // We don't touch vite-env.d.ts to simplify the process a bit
    (0, replaceStringValueInFile_1.replaceStringValueInFile)(path_1.default.join(dest, './vite.config.ts'), 'AMPLICODE_ENDPOINTS', authConfig_1.AUTH_DEFAULT_ENDPOINTS);
    (0, npmDeps_1.removeNpmDeps)(path_1.default.join(dest, 'package.json'), Object.keys(auth_oidc_keycloak_1.OIDC_KEYCLOAK_AUTH_DEPS));
}
exports.raResetAuth = raResetAuth;
function deleteFileSync(filePath) {
    console.log("raResetAuth: delete file ", filePath);
    fs_1.default.rmSync(filePath, { force: true, recursive: true });
}
//# sourceMappingURL=raResetAuth.js.map