"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceStringValueInFile = void 0;
const tslib_1 = require("tslib");
const jscodeshift_1 = tslib_1.__importDefault(require("jscodeshift"));
const ReplacementTargetNotFoundError_1 = require("../../../../building-blocks/stages/writing/pieces/source-utils/variables/ReplacementTargetNotFoundError");
const replaceStringValue_1 = require("../../../../building-blocks/stages/writing/pieces/source-utils/variables/replaceStringValue");
const fs_1 = tslib_1.__importDefault(require("fs"));
function replaceStringValueInFile(filePath, variableName, newValue) {
    const source = fs_1.default.readFileSync(filePath, 'utf-8');
    const tsParser = jscodeshift_1.default.withParser('ts');
    const ast = tsParser(source);
    try {
        (0, replaceStringValue_1.replaceStringValue)(ast, variableName, newValue);
        console.log(`replaceStringValue: set variable '${variableName}' to new value '${newValue}' in file ${filePath}`);
    }
    catch (error) {
        // TODO may be we should not catch this, just allow app fail
        if (error instanceof ReplacementTargetNotFoundError_1.ReplacementTargetNotFoundError) {
            console.log(`WARNING: Was trying to change ${variableName} in "${filePath}" ` +
                `to ${newValue}, but this file does not contain this variable. ` +
                `This may break the application.`);
            return;
        }
    }
    const output = ast.toSource();
    fs_1.default.writeFileSync(filePath, output);
}
exports.replaceStringValueInFile = replaceStringValueInFile;
//# sourceMappingURL=replaceStringValueInFile.js.map