"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const generatorPaths_1 = require("./generatorPaths");
const chai_1 = require("chai");
const path_1 = tslib_1.__importDefault(require("path"));
describe("generatorPaths", function () {
    it("should derive screen paths", function () {
        const dest = "/root/src/app/screens/pet";
        const relDirShift = "../../../";
        // screen path separator is OS-dependent, so we need to use `path.sep` in expected
        const separator = path_1.default.sep;
        const res = (0, generatorPaths_1.deriveScreenPaths)(dest, relDirShift);
        (0, chai_1.expect)(res.srcPath).to.equal(`${separator}root${separator}src${separator}`);
        (0, chai_1.expect)(res.relativeDestPath).to.equal(`app${separator}screens${separator}pet`);
    });
    it("should derive addon screen paths", function () {
        const dest = "/root/etpl-frontend/packages/addon-etpl/src/addon/component/common";
        const relDirShift = "../../../";
        const expected = Object.entries({
            addonSrcPath: `/root/etpl-frontend/packages/addon-etpl/src/`,
            addonRelativeDestPath: `addon/component/common`,
            screenDestPath: `/root/etpl-frontend/packages/addon-etpl/src/addon/component/common`,
            addonIndexFilePath: `/root/etpl-frontend/packages/addon-etpl/src/index.ts`,
            addonI18NPath: `/root/etpl-frontend/packages/addon-etpl/src/addon/i18n/messages`,
            metadataFilePath: `/root/etpl-frontend/packages/addon-etpl/amplicode.addon-metadata.json`,
            addonPackageJsonFilePath: `/root/etpl-frontend/packages/addon-etpl/package.json`,
            sampleAppSrcPath: `/root/etpl-frontend/sample-app/src`,
            sampleAppMenuFilePath: `/root/etpl-frontend/sample-app/src/app/menu/MainMenu.tsx`,
            sampleAppAppFilePath: `/root/etpl-frontend/sample-app/src/app/App.tsx`,
        })
            // replace `/` to OS specific separator in expected string values
            .reduce((prev, curr) => {
            // screen path separator is OS-dependent, so we need to use `path.sep` in expected
            (prev)[curr[0]] = curr[1].replaceAll('/', path_1.default.sep);
            return prev;
        }, {});
        const res = (0, generatorPaths_1.deriveAddonScreenPaths)(dest, relDirShift);
        const { addonI18NPath, addonSrcPath, addonRelativeDestPath, addonPackageJsonFilePath, addonIndexFilePath, metadataFilePath, sampleAppAppFilePath, sampleAppMenuFilePath, sampleAppSrcPath, screenDestPath } = res;
        (0, chai_1.expect)(addonI18NPath).to.eq(expected.addonI18NPath);
        (0, chai_1.expect)(addonSrcPath).to.eq(expected.addonSrcPath);
        (0, chai_1.expect)(addonRelativeDestPath).to.eq(expected.addonRelativeDestPath);
        (0, chai_1.expect)(addonIndexFilePath).to.eq(expected.addonIndexFilePath);
        (0, chai_1.expect)(addonPackageJsonFilePath).to.eq(expected.addonPackageJsonFilePath);
        (0, chai_1.expect)(metadataFilePath).to.eq(expected.metadataFilePath);
        (0, chai_1.expect)(sampleAppAppFilePath).to.eq(expected.sampleAppAppFilePath);
        (0, chai_1.expect)(sampleAppMenuFilePath).to.eq(expected.sampleAppMenuFilePath);
        (0, chai_1.expect)(sampleAppSrcPath).to.eq(expected.sampleAppSrcPath);
        (0, chai_1.expect)(screenDestPath).to.eq(expected.screenDestPath);
    });
});
//# sourceMappingURL=generatorPaths.test.js.map