"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mergeAddonSampleAppI18nFile_1 = require("./mergeAddonSampleAppI18nFile");
const chai_1 = require("chai");
describe("mergeAddonI18nFile", () => {
    const sampleAppFile = "" +
        `import { TranslationMessages } from "ra-core";
import englishMessages from "ra-language-english";
import { mergeMessages } from "./mergeMessages";

const messages: TranslationMessages = {
  ...englishMessages,
  resources: {},
  amplicode: {
    not_set: "Not set"
  }
};

export const en = mergeMessages(
  messages,
  [] // place addon messages here
);`;
    const sampleAppWithAddonObject = "" +
        `import { en as emailTemplatesMessages } from "@amplicode/addon-email-templates";
import { TranslationMessages } from "ra-core";
import englishMessages from "ra-language-english";
import { mergeMessages } from "./mergeMessages";

const messages: TranslationMessages = {
  ...englishMessages,
  resources: {},
  amplicode: {
    not_set: "Not set"
  }
};

export const en = mergeMessages(
  messages,
  [emailTemplatesMessages] // place addon messages here
);`;
    it("should add addon import and addon i18n object in file", () => {
        const mergedI18n = (0, mergeAddonSampleAppI18nFile_1.mergeAddonSampleAppI18nFile)(sampleAppFile, "en", "@amplicode/addon-email-templates", "emailTemplates");
        (0, chai_1.expect)(mergedI18n).containIgnoreSpaces(`
      import { en as emailTemplatesMessages } from "@amplicode/addon-email-templates";
      import { TranslationMessages } from "ra-core";
      import englishMessages from "ra-language-english";
      import { mergeMessages } from "./mergeMessages";
    `);
        (0, chai_1.expect)(mergedI18n).containIgnoreSpaces(`
      export const en = mergeMessages(
        messages,
        [emailTemplatesMessages] // place addon messages here
      );
    `);
    });
    it("should skip inserting addon import and object, if import already exist", () => {
        const mergedI18n = (0, mergeAddonSampleAppI18nFile_1.mergeAddonSampleAppI18nFile)(sampleAppWithAddonObject, "en", "@amplicode/addon-email-templates", "emailTemplates");
        (0, chai_1.expect)(mergedI18n).to.eq(sampleAppWithAddonObject);
    });
});
//# sourceMappingURL=mergeAddonSampleAppI18nFile.test.js.map