"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeI18nMessagesWithLocaleFile = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs/promises"));
const path = tslib_1.__importStar(require("path"));
const mergeI18nMessagesWithLocaleFileContent_1 = require("./mergeI18nMessagesWithLocaleFileContent");
/**
 * Find locale file by localeName in file system of generated app
 * then find variable with localeMessages by localeName
 * then merge (add if message with such key not exist) default i18n messages
 * with existing messages to locale file in file system
 *
 * @param localeMessagesPath - path of i18n messages dir
 * @param localeName - using to get locale file in i18n messages dir and find variable with locale messages inside
 * @param defaultI18nMessages - set of default messages of entity, or other item
 * this messages has low priority in merge, and will be added in result set only if there is no
 * messages with such keys in locale file
 * @param messagesVarName messages object in file, where which should be merged
 */
async function mergeI18nMessagesWithLocaleFile(localeMessagesPath, localeName, defaultI18nMessages, messagesVarName = "messages") {
    const localePath = path.join(localeMessagesPath, `${localeName}.ts`);
    const localeFile = await fs.readFile(localePath, "utf-8")
        .catch(() => {
        throw new Error(`File with '${localeName}' locale not found in '${localeMessagesPath}' dir`);
    });
    const localeFileContent = (0, mergeI18nMessagesWithLocaleFileContent_1.mergeI18nMessagesWithLocaleFileContent)(localeFile, messagesVarName, defaultI18nMessages);
    await fs.writeFile(localePath, localeFileContent, "utf-8");
}
exports.mergeI18nMessagesWithLocaleFile = mergeI18nMessagesWithLocaleFile;
//# sourceMappingURL=mergeI18nMessagesWithLocaleFile.js.map