"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const mergeI18nMessagesWithLocaleFileContent_1 = require("./mergeI18nMessagesWithLocaleFileContent");
const jscodeshift_1 = tslib_1.__importDefault(require("jscodeshift"));
const chai_1 = require("chai");
const getI18nMessages_1 = require("../../../../building-blocks/stages/template-model/pieces/getI18nMessages");
const toSource_1 = require("../../../../building-blocks/stages/writing/pieces/jsCodeShift/toSource");
describe("parseMessagesToNode", async () => {
    it("should parse simple string messages", () => {
        const astNode = (0, mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode)({
            messageOne: 'messageOne',
            messageTwo: 'messageTwo'
        });
        const stringMessages = (0, toSource_1.toSource)((0, jscodeshift_1.default)(astNode));
        (0, chai_1.expect)(stringMessages).to.deep.equal(`{
    messageOne: "messageOne",
    messageTwo: "messageTwo"
}`);
    });
    it("should parse SpreadElement inside messages", () => {
        const astNode = (0, mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode)({
            englishMessages: new getI18nMessages_1.SpreadElement()
        });
        const stringMessages = (0, toSource_1.toSource)((0, jscodeshift_1.default)(astNode));
        (0, chai_1.expect)(stringMessages).to.deep.equal(`{
    ...englishMessages
}`);
    });
    it("should parse deep string messages", () => {
        const astNode = (0, mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode)({
            levelOne: {
                levelTwo: {
                    messageOne: 'messageOne',
                    messageTwo: 'messageTwo'
                }
            }
        });
        const stringMessages = (0, toSource_1.toSource)((0, jscodeshift_1.default)(astNode));
        (0, chai_1.expect)(stringMessages).to.deep.equal(`{
    levelOne: {
        levelTwo: {
            messageOne: "messageOne",
            messageTwo: "messageTwo"
        }
    }
}`);
    });
    it("should parse all combination of possible messages", () => {
        const astNode = (0, mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode)({
            englishMessages: new getI18nMessages_1.SpreadElement(),
            messageOne: 'messageOne',
            messageTwo: 'messageTwo',
            levelOne: {
                levelTwo: {
                    messageOne: 'messageOne',
                    messageTwo: 'messageTwo'
                }
            }
        });
        const stringMessages = (0, toSource_1.toSource)((0, jscodeshift_1.default)(astNode));
        (0, chai_1.expect)(stringMessages).to.deep.equal(`{
    ...englishMessages,
    messageOne: "messageOne",
    messageTwo: "messageTwo",

    levelOne: {
        levelTwo: {
            messageOne: "messageOne",
            messageTwo: "messageTwo"
        }
    }
}`);
    });
});
//# sourceMappingURL=parseMessagesToNode.test.js.map