"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveGraphQLEditorModel = exports.deriveEntityEditorTemplateModel = void 0;
const tslib_1 = require("tslib");
const graphql_1 = require("graphql");
const graphql_tag_1 = tslib_1.__importDefault(require("graphql-tag"));
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const utils_1 = require("../../../common/utils");
const reactAdminUtilModel_1 = require("../common/reactAdminUtilModel");
const getI18nMessages_1 = require("../../../building-blocks/stages/template-model/pieces/getI18nMessages");
const raPrintSchema_1 = require("../common/raPrintSchema");
const deriveEntityEditorTemplateModel = async (options, answers, schema) => {
    const { detailsQuery: queryString, upsertMutation: mutationString, createComponentName: createComponentName, editComponentName: editComponentName, fileAttributesEditProperties, skipTestGeneration, } = answers;
    const queryNode = (0, graphql_tag_1.default)(queryString);
    const mutationNode = mutationString != null
        ? (0, graphql_tag_1.default)(mutationString)
        : undefined;
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...reactAdminUtilModel_1.reactAdminUtilModel,
        relDirShift: (0, utils_1.normalizeImportRelativePath)(options.dirShift),
        createComponentName,
        editComponentName,
        caption: 'TODO',
        // caption: splitByCapitalLetter(componentName),
        schema: schema ? (0, raPrintSchema_1.raPrintSchema)(schema) : undefined,
        ...deriveGraphQLEditorModel(queryNode, 'id', schema, mutationNode, fileAttributesEditProperties),
        // TODO problem with $id: String = "", quotation marks get messed up
        queryString,
        mutationString,
        // idField,
        skipTestGeneration: skipTestGeneration != null && skipTestGeneration,
    };
};
exports.deriveEntityEditorTemplateModel = deriveEntityEditorTemplateModel;
function deriveGraphQLEditorModel(queryNode, idField, schema, mutationNode, fileAttributesEditProperties) {
    if (schema == null) {
        throw new Error('Schema is required for this generator');
    }
    const queryOperationDefinition = queryNode.definitions[0];
    if (queryOperationDefinition.kind !== 'OperationDefinition') {
        throw new Error("Operation definition not found in query");
    }
    const idIsNotNull = queryOperationDefinition.variableDefinitions?.[0].type.kind === 'NonNullType';
    const queryName = (0, getTopFieldName_1.getTopFieldName)(queryNode);
    const entityName = (0, getEntityName_1.getEntityName)(queryName, schema);
    const allAttributes = (0, getAttributeNames_1.getAttributeNames)(entityName, schema);
    if (mutationNode == null) {
        const readOnlyAttributes = (0, getEntityAttributes_1.getEntityAttributes)(queryNode, schema, idField, fileAttributesEditProperties);
        const i18nMessages = (0, getI18nMessages_1.getI18nMessages)(entityName, readOnlyAttributes);
        return {
            queryName,
            idIsNotNull,
            attributes: readOnlyAttributes,
            entityName,
            allAttributes,
            i18nMessages
        };
    }
    const mutationOperationDefinition = mutationNode.definitions[0];
    if (!('variableDefinitions' in mutationOperationDefinition) || mutationOperationDefinition.variableDefinitions == null) {
        throw new Error('Variable definitions not found in mutation');
    }
    const inputVariableName = mutationOperationDefinition.variableDefinitions[0].variable.name.value;
    const inputType = mutationOperationDefinition.variableDefinitions[0].type;
    let inputTypeName;
    if ('name' in inputType) {
        inputTypeName = inputType.name.value;
    }
    if ('type' in inputType && 'name' in inputType.type) {
        inputTypeName = inputType.type.name.value;
    }
    if (inputTypeName == null) {
        throw new Error('Input type name not found');
    }
    const mutationName = (0, getTopFieldName_1.getTopFieldName)(mutationNode);
    const queryType = schema.getQueryType();
    if (queryType == null) {
        throw new Error('Query type not found');
    }
    const outputType = (0, graphql_1.getNamedType)(queryType.getFields()[queryName].type);
    if (!(0, graphql_1.isOutputType)(outputType)) {
        throw new Error('Output type name not found');
    }
    // We take attributes from query, otherwise it won't be possible to pair the entity type from editor with entity type from list
    const attributes = (0, getEntityAttributes_1.getEntityAttributes)(queryNode, schema, idField, fileAttributesEditProperties);
    const i18nMessages = (0, getI18nMessages_1.getI18nMessages)(entityName, attributes);
    return {
        queryName,
        idIsNotNull,
        mutationName,
        attributes,
        entityName,
        inputVariableName,
        inputTypeName,
        allAttributes,
        i18nMessages
    };
}
exports.deriveGraphQLEditorModel = deriveGraphQLEditorModel;
//# sourceMappingURL=template-model.js.map