"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveAdvancedListModel = void 0;
const tslib_1 = require("tslib");
const graphql_tag_1 = tslib_1.__importDefault(require("graphql-tag"));
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const getOperationDefinitionName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getOperationDefinitionName");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const getI18nMessages_1 = require("../../../building-blocks/stages/template-model/pieces/getI18nMessages");
const change_case_1 = require("change-case");
const utils_1 = require("../../../common/utils");
const deriveFilterModel_1 = require("./deriveFilterModel");
const reactAdminUtilModel_1 = require("../common/reactAdminUtilModel");
const raPrintSchema_1 = require("../common/raPrintSchema");
const deriveAdvancedListModel = async (options, answers, schema) => {
    if (schema == null) {
        throw new Error("Schema not found");
    }
    const { componentName, listQuery: queryString, deleteMutation: deleteMutationString, fileAttributesListProperties, orderByArguments, filterByArguments, paginationArgument, skipTestGeneration, } = answers;
    const queryNode = (0, graphql_tag_1.default)(queryString);
    const withDeleteMutation = !(0, utils_1.isBlank)(deleteMutationString);
    const deleteMutationName = withDeleteMutation ? (0, getTopFieldName_1.getTopFieldName)((0, graphql_tag_1.default)(deleteMutationString)) : undefined;
    const queryName = (0, getTopFieldName_1.getTopFieldName)(queryNode);
    const refetchQuery = (0, getOperationDefinitionName_1.getOperationDefinitionName)(queryNode);
    const attributes = (0, getEntityAttributes_1.getEntityAttributes)(queryNode, schema, "id", fileAttributesListProperties);
    const entityName = (0, getEntityName_1.getEntityName)(queryName, schema);
    const i18nMessages = (0, getI18nMessages_1.getI18nMessages)(entityName, attributes);
    const allAttributes = (0, getAttributeNames_1.getAttributeNames)(entityName, schema);
    const sortableAttrs = orderByArguments == null
        ? []
        : orderByArguments.map(arg => (0, change_case_1.camelCase)(arg));
    const { filters, withFilters } = (0, deriveFilterModel_1.deriveFilterModel)(queryName, filterByArguments == null ? [] : filterByArguments, schema);
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...reactAdminUtilModel_1.reactAdminUtilModel,
        relDirShift: (0, utils_1.normalizeImportRelativePath)(options.dirShift),
        schema: schema ? (0, raPrintSchema_1.raPrintSchema)(schema) : undefined,
        componentName,
        queryName,
        queryString,
        deleteMutationName,
        deleteMutationString,
        withDeleteMutation,
        attributes,
        allAttributes,
        sortableAttrs,
        refetchQuery,
        entityName,
        i18nMessages,
        filters,
        withFilters,
        resultDataPath: getResultDataPath(queryNode),
        withPagination: !(0, utils_1.isBlank)(paginationArgument),
        paginationArgument: paginationArgument,
        skipTestGeneration: skipTestGeneration != null && skipTestGeneration,
    };
};
exports.deriveAdvancedListModel = deriveAdvancedListModel;
/**
 * Result data path - path in query result where entity list is stored.
 * Returns 'content' for paging queries, or empty string in other cases.
 * @param documentNode query to be checked
 */
function getResultDataPath(documentNode) {
    const operation = documentNode.definitions[0];
    if (operation.kind !== 'OperationDefinition')
        throw new Error('Operation definition not found');
    const topField = operation.selectionSet.selections[0];
    if (topField.kind !== 'Field')
        throw new Error('topField can be only Field kind');
    const selectedFields = topField.selectionSet?.selections;
    if (selectedFields == null)
        throw new Error('Fields from topField aren\'t found');
    const content = selectedFields
        .find(field => field.kind === "Field"
        && field.name.value === "content"
        && Array.isArray(field.selectionSet?.selections));
    const totalElements = selectedFields
        .find(field => field.kind === "Field"
        && field.name.value === "totalElements");
    if (content != null
        && content.kind === 'Field'
        && content.selectionSet != null
        && totalElements != null) {
        return 'content';
    }
    return '';
}
//# sourceMappingURL=template-model.js.map