"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveGraphQLShowModel = exports.deriveEntityShowTemplateModel = void 0;
const tslib_1 = require("tslib");
const graphql_tag_1 = tslib_1.__importDefault(require("graphql-tag"));
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const utils_1 = require("../../../common/utils");
const reactAdminUtilModel_1 = require("../common/reactAdminUtilModel");
const getI18nMessages_1 = require("../../../building-blocks/stages/template-model/pieces/getI18nMessages");
const raPrintSchema_1 = require("../common/raPrintSchema");
const deriveEntityShowTemplateModel = async (options, answers, schema) => {
    const { detailsQuery: queryString, fileAttributesShowProperties, showComponentName: showComponentName, skipTestGeneration, } = answers;
    const queryNode = (0, graphql_tag_1.default)(queryString);
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...reactAdminUtilModel_1.reactAdminUtilModel,
        relDirShift: (0, utils_1.normalizeImportRelativePath)(options.dirShift),
        showComponentName,
        caption: "TODO",
        schema: schema ? (0, raPrintSchema_1.raPrintSchema)(schema) : undefined,
        ...deriveGraphQLShowModel(queryNode, "id", schema, fileAttributesShowProperties),
        // TODO problem with $id: String = "", quotation marks get messed up
        queryString,
        skipTestGeneration: skipTestGeneration != null && skipTestGeneration,
    };
};
exports.deriveEntityShowTemplateModel = deriveEntityShowTemplateModel;
function deriveGraphQLShowModel(queryNode, idField, schema, fileAttributesShowProperties) {
    if (schema == null) {
        throw new Error("Schema is required for this generator");
    }
    const queryOperationDefinition = queryNode.definitions[0];
    if (queryOperationDefinition.kind !== "OperationDefinition") {
        throw new Error("Operation definition not found in query");
    }
    const queryName = (0, getTopFieldName_1.getTopFieldName)(queryNode);
    const entityName = (0, getEntityName_1.getEntityName)(queryName, schema);
    const allAttributes = (0, getAttributeNames_1.getAttributeNames)(entityName, schema);
    const readOnlyAttributes = (0, getEntityAttributes_1.getEntityAttributes)(queryNode, schema, idField, fileAttributesShowProperties);
    const i18nMessages = (0, getI18nMessages_1.getI18nMessages)(entityName, readOnlyAttributes);
    return {
        queryName,
        attributes: readOnlyAttributes,
        entityName,
        allAttributes,
        i18nMessages
    };
}
exports.deriveGraphQLShowModel = deriveGraphQLShowModel;
//# sourceMappingURL=template-model.js.map