"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNewComponentPreview = exports.addComponent = exports.registerComponentPreviews = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const utils_1 = require("../../../common/utils");
const jscodeshift_1 = tslib_1.__importStar(require("jscodeshift"));
function registerComponentPreviews(fs, { destRoot, dirShift, pathPattern, componentFileName, componentClassName }, isDefaultExport, componentProps, registerComponentCallback = exports.addComponent) {
    let isComponentRegistered = false;
    const componentPreviewsDir = path_1.default.join(destRoot, dirShift ? dirShift : '');
    const componentPreviewsPath = path_1.default.join(componentPreviewsDir, 'dev', 'previews.tsx');
    const componentPath = `../${getRelativePath(componentPreviewsDir, destRoot)}/${componentFileName}`;
    if (fs.exists(componentPreviewsPath)) {
        const componentPreviewsContents = fs.read(componentPreviewsPath);
        fs.write(componentPreviewsPath, registerComponentCallback(componentPreviewsContents, { pathPattern, componentClassName, componentFileName, componentPath }, isDefaultExport, componentProps));
        isComponentRegistered = true;
    }
    return isComponentRegistered;
}
exports.registerComponentPreviews = registerComponentPreviews;
const addComponent = (componentPreviewsContents, { pathPattern, componentClassName, componentPath }, isDefaultExport, componentProps) => {
    const tsxParser = jscodeshift_1.default.withParser('tsx');
    const previewsAST = tsxParser(componentPreviewsContents);
    addComponentImport(previewsAST, isDefaultExport, componentClassName, componentPath);
    const newComponentPreview = getNewComponentPreview(pathPattern, componentClassName, componentProps);
    return addComponentToPreview(previewsAST, newComponentPreview);
};
exports.addComponent = addComponent;
function getRelativePath(routingDir, destRoot) {
    return (0, utils_1.convertToUnixPath)(path_1.default.relative(routingDir, destRoot));
}
function getNewComponentPreview(pathPattern, componentClassName, componentProps) {
    return `
  <ComponentPreview path="${pathPattern}">
    <${componentClassName} ${serializeComponentsProps(componentClassName, componentProps)}/>
  </ComponentPreview>`;
}
exports.getNewComponentPreview = getNewComponentPreview;
function addComponentImport(previewsAST, isDefaultExport, componentClassName, componentPath) {
    const allPreviewsImports = previewsAST.find(jscodeshift_1.ImportDeclaration);
    const componentImportDeclaration = (0, jscodeshift_1.importDeclaration)([isDefaultExport
            ? (0, jscodeshift_1.importDefaultSpecifier)((0, jscodeshift_1.identifier)(componentClassName))
            : (0, jscodeshift_1.importSpecifier)((0, jscodeshift_1.identifier)(componentClassName))
    ], (0, jscodeshift_1.stringLiteral)(componentPath), "value");
    allPreviewsImports
        .at(0)
        .insertAfter(componentImportDeclaration);
    return allPreviewsImports.toSource();
}
function addComponentToPreview(previewsAST, newComponent) {
    const previews = previewsAST.findJSXElements("Previews");
    const previewsParrentPaths = previews.paths();
    if (previewsParrentPaths.length) {
        const [{ value: { children } }] = previewsParrentPaths;
        children?.push((0, jscodeshift_1.stringLiteral)(newComponent));
        return previews.toSource();
    }
    return previews.toSource();
}
function serializeComponentsProps(componentClassName, componentProps) {
    if (componentClassName !== 'HooksPOCEdit')
        return "";
    return componentProps
        ? Object.entries(componentProps).map(([propName, propValue]) => {
            const serializedPropValue = serializePropValue(propValue);
            return `${propName}={${serializedPropValue}}`;
        }).join(" ")
        : "";
}
function serializePropValue(propValue) {
    switch (typeof propValue) {
        case 'string': return `'${propValue}'`;
        case 'object': return `${JSON.stringify(propValue)}`;
        case 'function': return `${propValue.toString()}`;
        default: return propValue;
    }
}
//# sourceMappingURL=previews-registartion.js.map