"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EDIT_WITHOUT_UPSERT_ERROR = exports.deriveManagementTemplateModel = void 0;
const template_model_1 = require("../entity-details/template-model");
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const util_1 = require("../../../building-blocks/stages/template-model/pieces/util");
const ScreenTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/ScreenTemplateModel");
const template_model_2 = require("../entity-list/template-model");
async function deriveManagementTemplateModel(options, answers, schema) {
    const { listComponentName, itemComponentName, route, type, multiselect = false, mode, listQuery, detailsQuery, upsertMutation, deleteMutation, shouldAddToMenu, filterByArguments, orderByArguments, paginationType, listIdField, detailsIdField } = answers;
    const entityDetailsTemplateModel = await (0, template_model_1.deriveEntityDetailsTemplateModel)(options, {
        componentName: itemComponentName,
        query: detailsQuery,
        mutation: upsertMutation,
        idField: detailsIdField
    }, schema);
    const entityListTemplateModel = await (0, template_model_2.deriveEntityListTemplateModel)(options, {
        componentName: listComponentName,
        route,
        type,
        multiselect,
        mode,
        query: listQuery,
        mutation: deleteMutation,
        shouldAddToMenu: false,
        filterByArguments,
        orderByArguments,
        paginationType,
        idField: listIdField
    }, schema);
    entityListTemplateModel.itemComponentName = itemComponentName;
    if (entityListTemplateModel.mode === 'edit' && entityDetailsTemplateModel.mutationString == null) {
        throw exports.EDIT_WITHOUT_UPSERT_ERROR;
    }
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...util_1.templateUtilities,
        ...(0, ScreenTemplateModel_1.deriveScreenTemplateModel)(options, { componentName: listComponentName + 'ScreenLayout', route, shouldAddToMenu }),
        menuItemName: listComponentName,
        entityListTemplateModel,
        entityDetailsTemplateModel
    };
}
exports.deriveManagementTemplateModel = deriveManagementTemplateModel;
exports.EDIT_WITHOUT_UPSERT_ERROR = new Error('Invalid combination of parameters. Edit mode was selected for entity list, but no upsert mutation was specified for entity details screen. ' +
    'Select a different mode if you want to create an entity list with a read-only details screen, ' +
    'or provide upsert mutation if you want to create an entity list with an editor.');
//# sourceMappingURL=template-model.js.map