"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveInsertedListFromArrayTemplateModel = void 0;
const util_1 = require("../../../building-blocks/stages/template-model/pieces/util");
const graphql_1 = require("graphql");
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const amplicodeGetMetadata_1 = require("../../../building-blocks/stages/metadata/amplicodeGetMetadata");
const utils_1 = require("../../../common/utils");
const isAnyLeafType_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/isAnyLeafType");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const deriveInsertedListFromArrayTemplateModel = async (options, answers, schema) => {
    if (schema == null) {
        throw new Error('Schema not found');
    }
    const { idField = 'id', actionBar = false, arrayAttributes = [] } = answers;
    const metadata = await (0, amplicodeGetMetadata_1.amplicodeGetMetadata)(options);
    const relDirShift = (0, utils_1.normalizeImportRelativePath)(options.dirShift);
    const { responseFile } = options;
    if (responseFile == null)
        throw new Error('Path for generating file with response not found');
    const types = schema.getTypeMap();
    const attributes = arrayAttributes.map(attr => {
        // workaround for make generator works without passing GraphQL type in `format`
        // for simple cases (string, number, boolean)
        // TODO should be removed after https://youtrack.haulmont.com/issue/AST-427
        if (attr.format != null) {
            let gqlType = types[attr.format];
            if (gqlType == null) {
                if (attr.tsType != null && attr.tsType.includes('string')) {
                    gqlType = types['String'];
                }
                if (attr.tsType != null && attr.tsType.includes('boolean')) {
                    gqlType = types['Boolean'];
                }
                if (attr.tsType != null && attr.tsType.includes('number')) {
                    gqlType = types['BigDecimal'];
                }
            }
            if (gqlType == null) {
                throw new Error(`No matched GraphQL type found for attribute with format '${attr.format}', attribute '${JSON.stringify(attr)}'`);
            }
            return {
                kind: 'gql',
                tsType: attr.tsType,
                name: attr.name,
                displayName: (0, utils_1.capitalizeFirst)((0, utils_1.splitByCapitalLetter)(attr.name)),
                type: attr.format,
                gqlType,
                enumOptions: gqlType instanceof graphql_1.GraphQLEnumType
                    ? gqlType.getValues()
                    : undefined,
                isSingleRelationField: !(0, isAnyLeafType_1.isAnyLeafType)(gqlType) && !(gqlType instanceof graphql_1.GraphQLList),
                isMultiRelationField: !(0, isAnyLeafType_1.isAnyLeafType)(gqlType) && gqlType instanceof graphql_1.GraphQLList,
                nestedAttributes: (0, isAnyLeafType_1.isAnyLeafType)(gqlType)
                    ? undefined
                    : (0, getAttributeNames_1.getAttributeNames)(attr.format, schema),
            };
        }
        return {
            kind: 'ts',
            tsType: attr.tsType,
            name: attr.name,
            displayName: (0, utils_1.capitalizeFirst)((0, utils_1.splitByCapitalLetter)(attr.name)),
        };
    });
    const idAttribute = attributes.find(attr => attr.name === idField);
    if (idAttribute == null)
        throw new Error('idAttribute is not found');
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...util_1.templateUtilities,
        attributes,
        studioVars: metadata.variables,
        idAttribute,
        responseFile,
        withActionBar: actionBar,
        relDirShift,
        schema: schema ? (0, graphql_1.printSchema)(schema, { commentDescriptions: true }) : undefined,
    };
};
exports.deriveInsertedListFromArrayTemplateModel = deriveInsertedListFromArrayTemplateModel;
//# sourceMappingURL=template-model.js.map