"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const amplicodeGetGraphQLSchema_1 = require("../../../../building-blocks/stages/graphql-schema/amplicodeGetGraphQLSchema");
const graphql_1 = require("graphql");
const chai_1 = require("chai");
const path = tslib_1.__importStar(require("path"));
describe('amplicodeGetGraphQLSchema', async () => {
    const RELATIVE_SCHEMA_PATH = './../../../../../../../scripts/schema/schema.graphqls';
    const RELATIVE_ADDON_SCHEMA_PATH = './../../../../../../../scripts/schema/defaultaddon.graphqls';
    it('should return schema from single relative path', async () => {
        const opts = {
            schema: [[RELATIVE_SCHEMA_PATH]]
        };
        const schemaStr = (0, graphql_1.printSchema)(await (0, amplicodeGetGraphQLSchema_1.amplicodeGetGraphQLSchema)(opts, __dirname));
        (0, chai_1.expect)(schemaStr).to.contain('type Mutation {');
        (0, chai_1.expect)(schemaStr).to.contain('type Query {');
        (0, chai_1.expect)(schemaStr).to.contain('notNullScalarsTestEntity(id: ID): NotNullScalarsTestEntity');
        (0, chai_1.expect)(schemaStr).to.contain('deleteNotNullScalarsTestEntity(id: ID): Void');
    });
    it('should return schema from single absolute path', async () => {
        const opts = {
            schema: [[path.join(__dirname, RELATIVE_SCHEMA_PATH)]]
        };
        const schemaStr = (0, graphql_1.printSchema)(await (0, amplicodeGetGraphQLSchema_1.amplicodeGetGraphQLSchema)(opts, ''));
        (0, chai_1.expect)(schemaStr).to.contain('type Mutation {');
        (0, chai_1.expect)(schemaStr).to.contain('type Query {');
        (0, chai_1.expect)(schemaStr).to.contain('notNullScalarsTestEntity(id: ID): NotNullScalarsTestEntity');
        (0, chai_1.expect)(schemaStr).to.contain('deleteNotNullScalarsTestEntity(id: ID): Void');
    });
    it('should return schema from multiple paths', async () => {
        const opts = {
            schema: [
                [path.join(__dirname, RELATIVE_SCHEMA_PATH), RELATIVE_ADDON_SCHEMA_PATH]
            ]
        };
        const schemaStr = (0, graphql_1.printSchema)(await (0, amplicodeGetGraphQLSchema_1.amplicodeGetGraphQLSchema)(opts, __dirname));
        console.log(schemaStr);
        (0, chai_1.expect)(schemaStr).to.contain('testEntity(id: ID): TestEntity');
        (0, chai_1.expect)(schemaStr).to.contain('deleteTestEntity(id: ID): Boolean!');
        (0, chai_1.expect)(schemaStr).to.contain('notNullScalarsTestEntity(id: ID): NotNullScalarsTestEntity');
        (0, chai_1.expect)(schemaStr).to.contain('deleteNotNullScalarsTestEntity(id: ID): Void');
    });
});
//# sourceMappingURL=amplicodeGetGraphQLSchema.test.js.map