"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_options_1 = require("../../common/cli-options");
const chai_1 = require("chai");
const amplicode_1 = require("../../building-blocks/stages/options/pieces/amplicode");
describe('cli options', function () {
    it('should return empty array if no options passed', function () {
        (0, chai_1.expect)((0, cli_options_1.extractAvailableOptions)().length).eq(0);
    });
    it('should return empty array if alias not set', function () {
        const optsConfig = { option1: { type: String } };
        (0, chai_1.expect)((0, cli_options_1.extractAvailableOptions)(optsConfig).length).eq(0);
    });
    it('should extract options from config', function () {
        const optionConfig = { alias: 'o1', type: String };
        const optsConfig = { option1: optionConfig };
        let res = (0, cli_options_1.extractAvailableOptions)(optsConfig);
        (0, chai_1.expect)(res[0].pattern).eq('-o1, --option1 [option1]');
        (0, chai_1.expect)(res[0].description).to.be.undefined;
        optionConfig['description'] = 'option one';
        res = (0, cli_options_1.extractAvailableOptions)(optsConfig);
        (0, chai_1.expect)(res[0].pattern).eq('-o1, --option1 [option1]');
        (0, chai_1.expect)(res[0].description).eq('option one');
    });
    it('should extract array option', function () {
        const availableOptions = (0, cli_options_1.extractAvailableOptions)(amplicode_1.amplicodeCommonOptionsConfig);
        const schemaOpt = availableOptions.find(item => item.pattern === '-s, --schema [schema...]');
        (0, chai_1.expect)(schemaOpt).not.undefined;
        (0, chai_1.expect)(schemaOpt.description).eq('specify path (or set of paths) to GraphQL schema');
    });
    it('should pick options from cmd', function () {
        const optionConfig = { alias: 'o1', type: String };
        const optsConfig = { option1: optionConfig };
        let res = (0, cli_options_1.pickOptions)({ opt: 123 }, optsConfig);
        (0, chai_1.expect)(res).to.be.empty;
        res = (0, cli_options_1.pickOptions)({ option1: 123 }, optsConfig);
        (0, chai_1.expect)(res['option1']).eq(123);
    });
    it('should pik array option', function () {
        const res = (0, cli_options_1.pickOptions)({ schema: ['schema1', 'schema2'] }, amplicode_1.amplicodeCommonOptionsConfig);
        (0, chai_1.expect)(res.schema.length).eq(2);
    });
});
//# sourceMappingURL=cli-options.test.js.map